******************************************************************************
      subroutine blacfx( chCard , nqh , ar1 )
      implicit none
*parse parameters off black body command
      character chCard*80
      integer nqh
      real ar1
*
      include "itrdim.par"
      include "limspc.par"
      include "te1ryd.par"
      include "bounds.com"
      include "range.com"
      include "spnorm.com"
      include "spec.com"
      include "sptype.com"
      include "radius.com"
      include "rdfalt.com"
      include "IOqq.com"
*
*     local variables
      logical lgEOL , lgMatch 
      integer i
      real fread , a , rlogl , dil
*
      nspec = min( nspec+1 , limspc )
*     type is blackbody
      chSpType(nspec) = 'BLACK'
*
*     these two are not used for this continuum shape
      cutoff(nspec,1) = 0.
      cutoff(nspec,2) = 0.
*
*     get the temperature
      i = 5
      slope(nspec) = fread( chCard , i , 76 , lgEOL )
*
*     there must be at least one number, the temperature
      if( lgEOL ) then
        write(qq,'('' There must be at least 1 number on a'',
     1  '' BLACKBODY command line.  Sorry.'')')
        stop
      endif
*
*     this is the temperature - make sure its linear in the end
*     there are two keys, LINEAR and LOG, that could be here,
*     else choose which is here by which side of 10
      if( (slope(nspec).le.10. .and..not.lgMatch('LINE',chCard) ) .or.
     1 lgMatch(' LOG',chCard) ) then
*       log option
        slope(nspec) = 10.**slope(nspec)
      endif
*
*     check that temp is not too low - could happen if log misused
      if( slope(nspec).lt.1e4 ) write(qq,'('' Is T(star)='',1P,E10.2,
     1'' correct???'')') slope(nspec)
*
*     now check that temp not too low - would peak below low
*     energy limit of the code
*     factor is temperature of 1 Ryd, egamry is high energy limit of code
      if( slope(nspec)/te1ryd .lt. emm ) then
        write(qq,'('' This temperature is very low - the blackbody '',
     1  ''will have significant flux low the low energy limit of '',
     2  ''the code, presently '',1p,e10.2,'' Ryd.'')') emm
        write(qq,'('' Was this intended?'')')
      endif
*
*     now check that temp not too high - would extend beyond high
*     energy limit of the code
*     factor is temperature of 1 Ryd, egamry is high energy limit of code
      if( slope(nspec)/te1ryd*2. .gt. egamry ) then
        write(qq,'('' This temperature is very high - the blackbody '',
     1  ''will have significant flux above the high energy limit of '',
     2  ''the code,'',1p,e10.2,'' Ryd.'')') egamry
        write(qq,'('' Was this intended?'')')
      endif
*
*     also possible to input log(total luminosity)=real log(l)
      a = fread( chCard , i , 76 , lgEOL )
      if( lgEOL ) then
*       there was not a second number on the line; check if LTE
        if( lgMatch( ' LTE' , chCard ) ) then
*         set energy density to LTE value
          nqh = min( nqh+1 , limspc )
*         check that stack of shape and luminosity specifications
*         is parallel, stop if not - this happens is background comes
*         BETWEEN another set of shape and luminosity commands
          if( nspec.ne.nqh ) then
            write(qq,'('' This command has come between a previous ''
     1      ,''ordered pair of continuum shape and luminosity '',
     2      ''commands.''/'' Reorder the commands to complete each'',
     3      ''continuum specification before starting another.'')')
            write(qq,'('' Sorry.'')')
            stop
          endif
          chSpNorm(nqh) = 'LUMI'
          a = log10(slope(nspec))
          rlogl = log10( 2.99792e10 * 7.56464e-15) + 4.*a
          if( radius.eq.0. ) then
            ar1 = rdfalt
            radius = 10.**ar1
          endif
          chRSpec(nqh) = 'SQCM'
          range(nqh,1) = emm
          range(nqh,2) = egamry
          totpow(nqh) = rlogl
        endif
        return
      endif
*
*     the second number will be some sort of luminosity
      nqh = min( nqh+1 , limspc )
*     check that stack of shape and luminosity specifications
*     is parallel, stop if not - this happens is background comes
*     BETWEEN another set of shape and luminosity commands
      if( nspec.ne.nqh ) then
        write(qq,'('' This command has come between a previous '',
     1  ''ordered pair of continuum shape and luminosity '',
     2  ''commands.''/'' Reorder the commands to complete each'',
     3  ''continuum specification before starting another.'')')
        write(qq,'('' Sorry.'')')
        stop
      endif
      chSpNorm(nqh) = 'LUMI'
*
*     a second number was entered, what was it?
      if( lgMatch( 'LUMI' , chCard ) ) then
        rlogl = a
        chRSpec(nqh) = '4 PI'
*
      else if( lgMatch( 'RADI' , chCard ) ) then
*       radius was entered, convert to total lumin
        rlogl = -3.147238 + 2.*a + 4.*log10(slope(nspec) )
        chRSpec(nqh) = '4 PI'
*
      else if( lgMatch( 'DENS' , chCard ) ) then
*       number was temperature to deduce energy density
*       number is linear if greater than 10, or if LINEAR appears on line
*       want number to be log of temperature at end of this
        if( lgMatch( 'LINE' , chCard ) .or. a.gt.10. ) then
            a = log10(a)
        endif
        rlogl = log10( 2.99792e10 * 7.56464e-15) + 4.*a
        if( radius.eq.0. ) then
           ar1 = rdfalt
           radius = 10.**ar1
        endif
        chRSpec(nqh) = 'SQCM'
*
      else if( lgMatch( 'DILU' , chCard ) ) then
*       number is dilution factor, if negative then its log
        if( a.lt.0. ) then
          dil = a
        else
          dil = log10( a )
        endif
        if( dil.gt.0. ) write(qq,'('' Is a dilution factor greater'',
     1  '' than one physical?'')')
*       this is LTE energy density
        a = log10(slope(nspec))
        rlogl = log10( 2.99792e10 * 7.56464e-15) + 4.*a
*       add on dilution factor
        rlogl = rlogl + dil
*
        if( radius.eq.0. ) then
           ar1 = rdfalt
           radius = 10.**ar1
        endif
        chRSpec(nqh) = 'SQCM'
*
      else
        write(qq,'('' I dont understand what the second number ''
     1  ,''was- keywords are LUMINOSITY, RADIUS, DILUTION, and '',
     2  ''DENSITY.'')')
        stop
      endif
*
      range(nqh,1) = emm
      range(nqh,2) = egamry
      totpow(nqh) = rlogl
*
      end
