******************************************************************************
      real function eovrlp( abund ,tauin , tauout , a , crsec , ipanu ,
     1 widl, escp , chCore )
      implicit none
*derive line continuum overlap radiative transfer by destruction probability
      real abund ,tauin , tauout , a , crsec , widl, escp
      integer ipanu 
      character chCore*4
*
      include "sqrtpi.par"
      include "ncell.par"
      include "rfield.com"
      include "opac.com"
      include "scatop.com"
      include "IOqq.com"
      include "opacon.com"
      include "eovrlpVar.com"
*
*     local variables
*     dest0 is the smallest destruction probability to return
*     changed from 1e-4 to 1e-8 june 15 95 due to excessive ots heating
*     in high metallicity models
      real dest0 , scale
      parameter (dest0=1e-8 , scale=2.)
      real fhummr , aa
*
*     computes "escape probability" due to continuum destruction of
*     scattering lines
*     EOVRLP destruction probability
*     ABUND density of lower level    TAUIN, TAUOUT inner, outer optical depth
*     A damping constant  CRSEC vel cross ssec IPANU pointer to  freq of line
*     deppler WIDL width of lines    ESCP escape prob for line
*
*     if esc prob gt 1 then line is masing - return small number for dest prob
      if( escp.ge.1.0 ) then
        eovrlp = dest0
        return
      endif
*     following used to trick microsoft powerstation compiler
*     into not generating a warning about these variables,
*     which are not now used
      aa = tauin / max(1.,tauout) * a
*
*     find continuum opacity
      conopc = opac( ipanu )
      if( .not.lgOpacOn ) then
*       opacity not yet defined on very first try
        eovrlp = dest0
        return
      endif
*
*     may be no population
      if( abund.le.0. .or. conopc.le.0. ) then
*       do not set this to dest0 since energy not then conserved
        beta = 0.
        eovrlp = 0.
        return
      endif
*
*     fac of 1.7 convert to Hummer convention for line opacity
      opacline = abund*sqrtpi *crsec/widl
      beta = conopc / ( opacline + conopc)
      beta = min( beta , 1. - escp)
*
      if( chCore.eq.'INCO' ) then
*        fits to Hummer and Kunasz 1980 Ap.J. 236,609.
*        the max value of 1e-3 is so that we do not go too far
*        beyond what Hummer and Kunasz did
         eovrlp = min(1e-3 , 8.5 * beta )
      else if( chCore.eq.'  K2' ) then
*        Doppler core only; a=0., Hummer 68
         eovrlp = fhummr( beta )
      else if( chCore.eq.'SIMP' ) then
*        this for debugging only
         eovrlp = 8.5 * beta
      else
         write(qq,'('' chCore of '',A4,'' not understood by EOVRLP.'')')
     1   chCore
         stop
      endif
*
      eovrlp = eovrlp / (1. + eovrlp)
      eovrlp = eovrlp * (1.-escp)
*begin sanity check
      if( eovrlp.lt.0. .or. eovrlp.gt.1.0 ) then
        write(qq,'('' EovrLp returns insane destruction probability, =''
     1  ,1p,e10.2)') eovrlp
        call ShowMe
        stop
      endif
*end sanity check
*
*     chng>> 99 apr 12, limit destruction prob in case where gas dominated by scattering.
*     in this case scattering is much more likely than absorption on this event */
	eovrlp = (1. - albedo(ipanu) ) * eovrlp + albedo(ipanu)*dest0
      end
