*********************************************************************
      subroutine GetAtlas
      implicit none
*rebin Kurucz stellar models to match energy grid of code
      include "ncell.par"
      include "rfield.com"
      include "corind.com"
      include "widflx.com"
      include "StarSize.com"
      include "StarBad.com"
      include "IOqq.com"
*
*     local variables
      integer i , j , nvals,nmods,n1,n2,imod,ierr
*
* This is a program to re-bin the Kurucz stellar models spectrum to match the 
* CLOUDY grid.  For short wavelengths I will use a power law extrapolation
* of the model values (which should be falling rapidly) if needed.  At long
* wavelengths I will assume Rayleigh-Jeans from the last stellar model point
* to extrapolate to 1 cm wavelength.
*
* This version uses power-law interpolation between the points of the stellar
* model.
*
      parameter (nvals=1221,nmods=412)
* nvals is the number of values per Kurucz model.  nmods is the total 
* number of models in the set.  The last two are the Vega and Solar models.
*
*     real freq(ncell)
*     all freq changed to anu2
*     real flux2(ncell)
*     all flux2 changed to ContBoltz
*
      real teff(nmods),xlogg(nmods)
      integer iteff(ncell),logg(ncell)
      real wlin(nvals),flin(nvals)
*
      write(qq,'('' GetAtlas on the job.'')')
*
      n1 = 1
      do while( anu(n1).lt.10.)
        n1 = n1 + 1
      end do
      n1 = n1 - 1
*
       write(qq,'('' A total of '',i4,'' Cloudy cells needed.'')') n1
       if( n1.eq.nAtlas ) then
         write(qq,'('' The current value of nAtlas is ok.'')')
       else
         if( .not.lgStarBad ) then
*          no errors yet, so open errors file
           open(unit=66,file='problems.out',status='unknown')
         endif
         lgStarBad = .true.
         write(qq,'('' WARNING!!!!!'')')
         write(qq,'('' WARNING!!!!!'')')
         write(66,'('' nAtlas must be changed to'',i6,
     1   '' in block data scalar.  Its current value is'',i6)')
     2   n1,nAtlas
         write(qq,'('' nAtlas must be changed to'',i6,
     1   '' in block data scalar.  Its current value is'',i6)')
     2   n1,nAtlas
         write(qq,'('' I will take care of this for now.'')')
         nAtlas = n1
       endif
*
*     open(unit=01,file='kurucz.ascii',status='old',iostat=ierr,
*    c     access='direct',form='formatted',recl=12210)
      open(unit=01,file='kurucz.ascii',status='old',iostat=ierr)
      if( ierr.eq.0. ) then
        write(qq,'('' GetAtlas got kurucz.ascii.'')')
      else
        write(qq,'('' GetAtlas could not find kurucz.ascii.'')')
        stop
      endif
      open(unit=02,file='kurucz.list',status='old',iostat=ierr)
      if( ierr.eq.0. ) then
        write(qq,'('' GetAtlas got kurucz.list.'')')
      else
        write(qq,'('' GetAtlas could not find kurucz.list.'')')
        stop
      endif
*     read(01,40,rec=1,iostat=ierr) (wlin(i),i=1,nvals)
*     >>chng 97 jan 5, to get rid of format
      read(01,'(5e15.7)',iostat=ierr) (wlin(i),i=1,nvals)
*40   format(5e15.7)
*40   format(1221e10.3)
      if( ierr.eq.0. ) then
        write(qq,'('' GetAtlas got kurucz wavelengths, low high='',1p,
     1  2e11.3)') wlin(1), wlin(nvals)
      else
        write(qq,'('' GetAtlas could not read kurucz wavelengths.'')')
        stop
      endif
*
* the wavelength values wlin are in nm units, convert to freq (Hz)
* the energy range is 5.7e-4 to 10 Ryd
*
      do i=1,nvals
        anu2(i)=299792458.e+09/wlin(i)
      end do
*
*     first line is header
      read(02,'(11x)',iostat=ierr)
      do j=1,nmods
        read(02,'(11x,f8.1,8x,f7.5)',iostat=ierr) teff(j),xlogg(j)
*       write(qq,'(1p,2e10.2)') teff(j) , xlogg(j)
        if( ierr.ne.0 ) then
          write(qq,'('' GetAtlas failed readin teff, logg, for model'',
     1    i4)') j
          stop
        endif
        iteff(j)=teff(j)
        logg(j)=xlogg(j)*100000.
      end do
      write(qq,'('' Got grid of temperatures and gravities.'')')
*
      close(unit=02)
      open(unit=03,file='atlas.mod',access='direct',status='unknown',
     c     form='formatted',iostat=ierr, recl=7*ncell)
      if( ierr.ne.0 ) then
        write(qq,'('' GetAtlas failed creating kurucz.mod.'')')
        stop
      endif
*
*     >>chng 97 jan 5, get rid of format
      write(03,'(4000i7)',rec=1,iostat=ierr) (iteff(j),j=1,nmods)
*     this 4000 below is the value of ncell, and must be changed
*     if ncell changes
*65   format(4000i7)
      if( ierr.ne.0 ) then
        write(qq,'('' GetAtlas failed writing Teff.'')')
        stop
      endif
      write(03,'(4000i7)',rec=2,iostat=ierr) (logg(j),j=1,nmods)
      if( ierr.ne.0 ) then
        write(qq,'('' GetAtlas failed writng grav.'')')
        stop
      endif
*
      do j=1,n1
        iteff(j) = int(abs(log10(anu(j))-5.)*1000000.)
      end do
*
* *** NOTE ****  WARNING!!!!! ******
* As things are written here, the CLOUDY grid range covered by the models
* must be > 1.0e-05 Rydbergs and < 100000.0 Rydbergs so that the integer
* values are not larger than 9,999,999 and are all negative before the abs
* function is applied to the value to make the iteff element.  6 digits are
* needed in the logarithm value to give 5 digit accuracy when the values are
* converted back to energy values in Rydbergs by programs reading the model
* file.  For the present Werner and Kurucz models these limits are not a
* problem, nor are these limits likely to be violated in the future by purely
* stellar models....but if the limits are exceeded, things will not work.
*
* Since the Kurucz models cover up to a temperature of 50000 K and there is 
* no significant emission at very high energies, the range of energy covered 
* by the rebinning does not have to extend beyond a few Rydberg.  Here 10 Rydb 
* is used to be consistent with the output from the hotter Werner models.
*
*     write out the cloudy energy grid for later sanity checks
      write(03,'(4000i7)',rec=3,iostat=ierr) (iteff(j),j=1,n1)
      if( ierr.ne.0 ) then
        write(qq,'('' GetAtlas failed writng anu array.'')')
        stop
      endif
*
      do j=1,n1
        iteff(j)=0
      end do
*
* This array will now be used for writing out the flux values in log form,
* multiplied by 1.e+05 and converted to integer (this allows sign plus 7
* integer places, storing 5 places in the log10 value which gives 4 significant
* figure accuracy in the values).
*
      write(6,'(///)')
      write(6,'('' Now would be a good time to get on the Cloudy '',
     1''mailing list, to'')')
      write(6,'('' find out about corrections and improvements to '',
     1''the code.'')')
      write(6,'('' Send a request to cldmail@pa.uky.edu'')')
      write(6,'(///)')
      write(6,'('' I will print every 10th model so you know I am '',
     1 ''still alive.'')')
      write(6,'('' (there are 412 models)'')')
      do imod=1,412
*       read(01,40,rec=imod+1,iostat=ierr) (flin(i),i=1,nvals)
*     >>chng 97 jan 5, to get rid of format
        read(01,'(5e15.7)',iostat=ierr) (flin(i),i=1,nvals)
        if( ierr.ne.0 ) then
          write(qq,'('' GetAtlas failed reading star flux.'')')
          stop
        endif
*
        do j=1,nvals
          flux(j) = max(1e-35, flin(j) )
        end do
*
        n2 = nvals
*
* This value is 1 larger than the value of n1.
        call RebinAtlas(n1,n2)
        do j=1,n1
          if (ContBoltz(j).gt.1e-30) then
            iteff(j) = int(abs(log10(ContBoltz(j)))*100000.)
          else
*           this is smallest possible number
            iteff(j)=9999999
          endif
        end do
*
        write(03,'(4000i7)',rec=imod+3,iostat=ierr) (iteff(j),j=1,n1)
*       write(66,'(9i8) (iteff(j),j=1,n1)
        if( ierr.ne.0 ) then
          write(qq,'('' GetAtlas failed writing iteff star flux.'')')
          stop
        else if( imod/10*10 .eq.imod ) then
          write(qq,'('' GetAtlas wrote'',i4)') imod
        endif
      end do
*
      close(unit=01)
      close(unit=03)
      write(qq,'('' GetAtlas complete, kurucz files may be deleted.'')')
      end
