************************************************************************
      subroutine GetRauch
      implicit none
*rebin Rauch stellar models to match energy grid of code
*     limit to number of cells in frequency array
*     NB is this every is changed, also need to change formats in
*     Kevin Volk's stellar atmospheres codes
      include "ncell.par"
      include "pi.par"
      include "rfield.com"
      include "widflx.com"
      include "StarSize.com"
      include "StarBad.com"
      include "IOqq.com"
*
*     local variables
      integer i , j , k, nvals,nmods,n1,n2,imod,ierr
*
* This subroutine re-bins the Rauch atmosphere fluxes to match the Cloudy
* grid.  The wavelengths of the Rauch models are 5.0 to 2000.0 angstroms 
* with a step size of 0.1 angstroms, 19951 points each.  Thus the wavelength
* grid is not saved in the file of ascii values.  The values in the file are 
* F_lambda values in erg/s/cm^2/cm.  They have to be multiplied by pi to get 
* the "real" surface flux.  Then I convert them into F_nu in erg/s/cm^2/Hz 
* by taking 1.e-18 * wavelength^2 * F_lambda / c.  The factor 1.e-18 is 
* due to the wavelengths being in angstroms.
*
* With some many points I need to average over the Cloudy grid rather than 
* interpolating as is the case for the Kurucz or Werner models.  At short 
* wavelengths the two grids are of similar spacing.
*
      parameter (nvals=19951,nmods=66)
      real stflux(nvals)
*     nvals is the number of values per Rauch model.  nmods is the total
*     number of models in the set.
*
*     real teff(nmods)
*     real xlogg(nmods)
      integer iteff(ncell)
      real wlin(nvals),flin(nvals)
*     data teff/50000.,50000.,50000.,50000.,60000.,60000.,60000.,60000.,
*    1          70000.,70000.,70000.,70000.,80000.,80000.,80000.,80000.,
*    2          90000.,90000.,90000.,90000.,100000.,100000.,100000.,
*    3          100000.,110000.,110000.,110000.,120000.,120000.,120000.,
*    4          130000.,130000.,130000.,140000.,140000.,140000.,
*    5          150000.,150000.,150000.,160000.,160000.,160000.,
*    6          170000.,170000.,170000.,180000.,180000.,180000.,
*    7          190000.,190000.,190000.,200000.,200000.,200000.,
*    8          300000.,300000.,300000.,400000.,400000.,500000.,
*    9          500000.,600000.,700000.,800000.,900000.,1000000./
*     data xlogg/5.,6.,7.,8.,5.,6.,7.,8.,5.,6.,7.,8.,5.,6.,7.,8.,
*    1           5.,6.,7.,8.,5.,6.,7.,8.,6.,7.,8.,6.,7.,8.,6.,7.,
*    2           8.,6.,7.,8.,6.,7.,8.,6.,7.,8.,6.,7.,8.,6.,7.,8.,
*    3           6.,7.,8.,7.,8.,9.,7.,8.,9.,8.,9.,8.,9.,9.,9.,9.
*    4           9.,9./
*
      write(qq,'('' GetRauch on the job.'')')
*
      n1 = 1
*     be sure not to clobber the anu array - will be used by other subs
      do while( anu(n1).lt.150.)
        n1 = n1 + 1
      end do
      n1 = n1 - 1
*
       write(qq,'('' A total of '',i4,'' Cloudy cells needed.'')') n1
       if( n1.eq.nRauch ) then
         write(qq,'('' The current value of nRauch is ok.'')')
       else
         if( .not.lgStarBad ) then
*          no errors yet, so open errors file
           open(unit=66,file='problems.out',status='unknown')
         endif
         lgStarBad = .true.
         write(qq,'('' WARNING!!!!!'')')
         write(qq,'('' WARNING!!!!!'')')
         write(66,'('' nRauch must be changed to'',i6,
     1   '' in block data scalar.  Its current value is'',i6)')
     2   n1,nRauch
         write(qq,'('' nRauch must be changed to'',i6,
     1   '' in block data scalar.  Its current value is'',i6)')
     2   n1,nRauch
         write(qq,'('' I will take care of this for now.'')')
         nRauch = n1
       endif
*
      do k=1,2
      if (k.eq.1) then
        open(unit=01,file='rauch_solar.ascii',status='old',
     1       iostat=ierr)
        if( ierr.eq.0. ) then
          write(qq,'('' GetRauch got rauch_solar.ascii.'')')
        else
          write(qq,'('' GetRauch could not find rauch_solar.ascii.'')')
          stop
        endif
*
        do i=1,nvals
          wlin(i)=2000.-0.1*float(i-1)
*         anu2(i)=299792458.e+10/wlin(i)
        end do
* anu2 now has the frequencies in Hz.
*
* the frequencies are in increasing order; when the fluxes are 
* read in they will have to be put in reverse order since they go from 
* 5 to 200 angstroms.
*
        open(unit=03,file='rauch_solar.mod',access='direct',
     1       status='unknown',form='formatted',iostat=ierr, 
     2       recl=7*ncell)
        if( ierr.ne.0 ) then
          write(qq,'('' GetRauch failed creating rauch_solar.mod.'')')
          stop
        endif
*
      else 
          open(unit=01,file='rauch_halo.ascii',status='old',
     1    iostat=ierr)
        if( ierr.eq.0. ) then
          write(qq,'('' GetRauch got rauch_halo.ascii.'')')
        else
          write(qq,'('' GetRauch could not find rauch_halo.ascii.'')')
          stop
        endif
*
        open(unit=03,file='rauch_halo.mod',access='direct',
     1       status='unknown',form='formatted',iostat=ierr,
     2       recl=7*ncell)
        if( ierr.ne.0 ) then
          write(qq,'('' GetRauch failed creating rauch_halo.mod.'')')
          stop
        endif
*
      endif

      do j=1,n1
        iteff(j) = int(abs(log10(anu(j))-5.)*1000000.)
      end do
*
* *** NOTE ****  WARNING!!!!! ******
* As things are written here, the CLOUDY grid range covered by the models
* must be > 1.0e-05 Rydbergs and < 100000.0 Rydbergs so that the integer
* values are not larger than 9,999,999 and are all negative before the abs
* function is applied to the value to make the iteff element.  6 digits are
* needed in the logarithm value to give 5 digit accuracy when the values are
* converted back to energy values in Rydbergs by programs reading the model
* file.  For the present Werner and Kurucz models these limits are not a
* problem, nor are these limits likely to be violated in the future by purely
* stellar models....but if the limits are exceeded, things will not work.
*
* The Rauch models go down to 5 Angstroms (about 182 Rydb) but I choose to 
* terminate the array at 150 Rydb since the fluxes are extremely small at
* the shortest wavelengths -- 17 orders of magnitude below peak for the 
* 500000 K model.  This differs a bit from the handling of the Werner models
* even though the temperature range is similar.
*
*     write out the cloudy energy grid for later sanity checks
      write(03,'(4000i7)',rec=1,iostat=ierr) (iteff(j),j=1,n1)
      if( ierr.ne.0 ) then
        write(qq,'('' GetRauch failed writng anu array.'')')
        stop
      endif
*
      do j=1,n1
        iteff(j)=0
      end do
*
* This array will now be used for writing out the flux values in log form,
* multiplied by 1.e+05 and converted to integer (this allows sign plus 7
* integer places, storing 5 places in the log10 value which gives 4 significant
* figure accuracy in the values).
*
      do imod=1,nmods
        read(01,'(9e9.3)',iostat=ierr) (flin(i),i=1,nvals)
        if( ierr.ne.0 ) then
          write(qq,'('' GetRauch failed reading star flux.'')')
          stop
        endif
*
        do j=1,nvals
          stflux(j) = max(1e-35, flin(nvals+1-j))
*         there should be no values that underflow in the file.
          stflux(j) =pi*wlin(j)*wlin(j)*1.e-18*stflux(j)/299792458.
          stflux(j) = max(1e-35, stflux(j))
        end do
*
        n2 = nvals
*
        call RebinRauch(stflux,wlin,flin)
*       the re-binned values are returned in the "flin" array
*
        do j=1,n1
          if (flin(j).gt.1e-30) then
            iteff(j) = int(abs(log10(flin(j))-3.)*100000.)
          else
*           this is smallest possible number
            iteff(j)=9999999
          endif
        end do
*
        write(03,'(4000i7)',rec=imod+1,iostat=ierr) (iteff(j),j=1,n1)
        if( ierr.ne.0 ) then
          write(qq,'('' GetRauch failed writing iteff star flux.'')')
          stop
        else 
          write(qq,'('' GetRauch wrote stellar model number'',
     1          i4)') imod
        endif
      end do
*
      close(unit=01)
      close(unit=03)
      if (k.eq.1) then
        write(qq,'('' GetRauch finished set 1, rauch_solar.ascii '',
     1        ''file may be deleted.'')')
      else
        write(qq,'('' GetRauch complete, rauch_halo.ascii file '',
     1        ''may be deleted.'')')
      end if
      enddo
      end
