************************************************************************
       subroutine h1cs123(i,j,temp,cs)
       implicit none
*hydrogen collision data
       integer i,j,k
       real cs,  temp
       include "IOqq.com"
* These are fits given in 
*      >>refer Callaway, J. 1994, ADNDT, 57, 9
* H I collision strengths for 1s-2s, 1s-2p, 1s-3, 2s-3, and 2p-3, 
* principle quantum numbers n and l.
* CLOUDY sums angular momentum (s,p,d) components of level n=3.
*
* SEE IMPORTANT NOTE BELOW ABOUT EST. VALID ENERGY RANGES OF FITS.
************************************************************************
*
* i is the lower level and runs from 1 to 3 (1s, 2s, 2p)
* j is the upper level and runs from 2 to 4 (2s, 2p, 3)
*
       real b(10)
       real cs3s, cs3p, cs3d
       real ev, bk, ryd, E
       real T, Tmin, Tmax1, Tmax2, Tmax3
*
* some constants
*
        ev = 1.60184e-12
        bk = 1.380622e-16 
        ryd = 13.60583

* convert temperature T (K) to energy in Rydbergs

        E = bk*temp/(ev*ryd)
        T = E

**********************************************************
*************-----------IMPORTANT------------*************
**********************************************************
*
* Callaway fits to effective cross-sections are high-order 
* polynomials which become insane not too far from the  
* unstated upper energy limits, given below. 
* Fits are more stable at low energy and here the validity 
* of cross-sections limits the validity of the fits.
*
* give energy limits for validity of fits:
* minimum energy = 0.01 Rydbergs (about 1580K)
*
        Tmin = 0.01
*
* 1s - 2s,2p maximum energy = 4 Rydbergs (~ 632,000K)
*
        Tmax1 = 4.0
* 
* 1s - 3 max energy is 1.2667 Rydberg (200,000K)
*
        Tmax2 = 1.2667
*
* 2s,p - 3 max energy is 1.0 Rydberg (158,888K)
*
        Tmax3 = 1.0
*
**********************************************************
* initialize cs
        cs = 0.
*
**************fits begin here**************
*
       if( i .eq. 1 .and. j .eq. 2 ) then
*
* check temperature: 
*
       if(T .gt. Tmax1) then
         T = Tmax1
       else if (T .lt. Tmin) then
         T = Tmin
       endif
*
* 1s - 2s
         b(1) = 2.5501041e-01
         b(2) = 9.973588e-02
         b(3) = -5.404749e-02
         b(4) = 2.520311e-02
         b(5) = -4.05306e-03
         b(6) = 3.508995e-02
         b(7) = 28.056
         b(8) = 7.2945
*
         cs = 0.
         do k = 1, 5
           cs = cs + b(k)*T**(k-1) 
         end do
*
         cs = cs + b(6)*alog(b(7)*T)*exp(-b(8)*T)
*
       else if ( i .eq. 1 .and. j .eq. 3 ) then
*
* check temperature: 
*
       if(T .gt. Tmax1) then
         T = Tmax1
       else if (T .lt. Tmin) then
         T = Tmin
       endif
*
* 1s - 2p
         b(1) = 3.6105477e-01
         b(2) = 1.73103797
         b(3) = 3.7297254e-01
         b(4) = -4.3240114e-01
         b(5) = 1.4296095e-01
         b(6) = -1.670572e-02
*
         cs = 0.
         do k = 1, 6
           cs = cs + b(k)*T**(k-1) 
         end do
*
       else if ( i .eq. 1 .and. j .eq. 4 ) then
*
* check temperature: 

       if(T .gt. Tmax2) then
         T = Tmax2
       else if (T .lt. Tmin) then
         T = Tmin
       endif
*
* 1s - 3s
         b(1) = 6.461453e-02
         b(2) = -1.1160826e-01
         b(3) = 7.6957269e-01
         b(4) = -2.18918875
         b(5) = 3.14216481
         b(6) = -2.23498961
         b(7) = 6.2651998e-01
         b(8) = 1.12515e-02
         b(9) = 28.056
         b(10) = 7.2945
*
         cs3s = 0.
         do k = 1, 7
           cs3s = cs3s + b(k)*T**(k-1) 
         end do
*
         cs3s = cs3s + b(8)*alog(b(9)*T)*exp(-b(10)*T)
*
* 1s - 3p
         b(1) = 9.895325e-02
         b(2) = 2.3240113e-01
         b(3) = 2.0112555e-01
         b(4) = 8.7813331e-01
         b(5) = -3.34239518
         b(6) = 3.7075526
         b(7) = -1.37320827
*
         cs3p = 0.
         do k = 1, 7
           cs3p = cs3p + b(k)*T**(k-1) 
         end do
*
* 1s - 3d
         b(1) = 5.742134e-02
         b(2) = -6.09531e-03
         b(3) = 9.3848281e-01
         b(4) = -3.40393911
         b(5) = 5.50742903
         b(6) = -4.25196238
         b(7) = 1.2687104
         b(8) = 7.24136e-03
         b(9) = 28.056
         b(10) = 7.2945
*
         cs3d = 0.
         do k = 1, 7
           cs3d = cs3d + b(k)*T**(k-1) 
         end do
*
         cs3d = cs3d + b(8)*alog(b(9)*T)*exp(-b(10)*T)

* Summed cs: 1s - 3 
         cs = cs3s + cs3p + cs3d
*
       else if (i .eq. 2 .and. j .eq. 4) then
*
* check temperature: 
*
       if(T .gt. Tmax3) then
         T = Tmax3
       else if (T .lt. Tmin) then
         T = Tmin
       endif
*
* 2s - 3s
         b(1) = 1.2168
         b(2) = 4.7349
         b(3) = 6.5942
         b(4) = -14.9419
         b(5) = 10.7255
         b(6) = -3.3407
         b(7) = 0.3823
* 
         cs3s = 0.
         do k = 1, 7
           cs3s = cs3s+ b(k)*T**(k-1) 
         end do
*
* 2s - 3p
         b(1) = 1.9985
         b(2) = 13.2632
         b(3) = 11.9120
         b(4) = -13.0364
         b(5) = 5.6720
         b(6) = -1.2155
         b(7) = 0.1034
*
         cs3p = 0.
         do k = 1, 7
           cs3p = cs3p + b(k)*T**(k-1) 
         end do
*
* 2s - 3d
         b(1) = 0.9382
         b(2) = 32.8948
         b(3) = -17.9286
         b(4) = -0.8772
         b(5) = 5.8667
         b(6) = -2.4439
         b(7) = 0.3147
*
         cs3d = 0.
         do k = 1, 7
           cs3d = cs3d + b(k)*T**(k-1) 
         end do
*
* Summed cs: 2s - 3 
         cs = cs3s + cs3p + cs3d
*
       else if (i .eq. 3 .and. j .eq. 4) then
*
* check temperature: 
*
       if(T .gt. Tmax3) then
         T = Tmax3
       else if (T .lt. Tmin) then
         T = Tmin
       endif
*
* 2p - 3s
         b(1) = 2.0097
         b(2) = 3.7515
         b(3) = -7.9734
         b(4) = 10.9359
         b(5) = -7.1074
         b(6) = 2.1359
         b(7) = -0.2405
*
         cs3s = 0.
         do k = 1, 7
           cs3s = cs3s + b(k)*T**(k-1) 
         end do
*
* 2p - 3p
         b(1) = 6.5316
         b(2) = 26.8258
         b(3) = -18.2834
         b(4) = 2.22
         b(5) = 4.1958
         b(6) = -2.0916
         b(7) = 0.289
*
         cs3p = 0.
         do k = 1, 7
           cs3p = cs3p + b(k)*T**(k-1) 
         end do
*
* 2p - 3d
         b(1) = 8.9833
         b(2) = 126.0513
         b(3) = -21.9017
         b(4) = 20.7445
         b(5) = -20.3788
         b(6) = 7.3643
         b(7) = -0.9082
*
         cs3d = 0.
         do k = 1, 7
           cs3d = cs3d + b(k)*T**(k-1) 
         end do
*
* Summed cs: 2p - 3
         cs = cs3s + cs3p + cs3d
*
       else 
         write(qq,*) '  insane levels for H I n=1,2,3 !!!'
         stop
       endif
*
      end
