******************************************************************************
      subroutine he2col
      implicit none
*evaluate collisional rates for model helium ion
      include "nhe2lvl.par"
      include "TePowers.com"
      include "phe2lv.com"
      include "heclon.com"
      include "c2pson.com"
      include "he2ind.com"
      include "casbhs.com"
      include "hebug.com"
      include "trace.com"
      include "phycon.com"
      include "he2blt.com"
      include "he2crt.com"
      include "he2cbr.com"
      include "he2stat.com"
      include "the2lo.com"
      include "He2deltaT.com"
      include "IOqq.com"
*
*     local variables
      integer i , j , n , iup , lo,ihi , ized
      real hd , tsq,t3,t4,cs12s,cs12p,hsfac,cs13,
     1 cs23,cs2s3s,cs2p3s, sum, told,f  , sexp

*
*     free statement labels, >=9
*
      real r1n(9) , r2n(9)
      real HydColIon , HydColDwn
      save told
*
       data 
     3 r1n/3*0., 1.05e-8, 3.45e-9, 1.54e-9, 3.23e-10,2.14e-11,7.09E-14/
     4,r2n/2*0.,7.88e-8,1.14e-8,3.10e-9,1.10e-9,2.0e-10,1.0e-11,2.8E-14/
*
       data told/0./
*
* 666 error! this routine is constantly evaluated, and does not
*    protect itself from reevaluating coef at the same temperature.
*    this is an obvious simple speed up
*
*     define boltz facs between adjacent levels
      do iup=2,nhe2lvl
*       he2deltaTe is array of line temps, upper to lower
*       their boltzmann factors for this temp
        he2bol(iup-1,iup) = exp(-dble(He2deltaTe(iup,iup-1)/te))
      end do
*     this is 1s-2s
      he2bol(1,nhe2lvl+1) = he2bol(1,2)
*
*     the highest level, up to the continuum
      he2cbt(nhe2lvl) = exp( -dble(He2CionTe(nhe2lvl)/te) )
*
*     define remaining Boltzmann factors
      do j=1,nhe2lvl-2
        do i=j+2,nhe2lvl
          he2bol(j,i) = he2bol(j,i-1) * he2bol(i-1,i)
        end do
      end do
      do i=1,nhe2lvl-1
        he2cbt(i) = he2bol(i,nhe2lvl) * he2cbt(nhe2lvl)
      end do
      he2cbt(nhe2lvl+1) = he2cbt(2)
*
*-------------------------------------------------------------
*
*     define HE2LTE(I) = lte population (cm^3) / Ne Np
*     only used in HE2LEV if Te>1000K
      if( te.ge.the2lo*0.9 ) then
        f = 2.0708e-16 / te32
        do i=1,nhe2lvl
          he2lte(i) = he2stat(i) /  he2cbt(i) * f
        end do
        he2lte(nhe2lvl+1) = he2stat(nhe2lvl+1)/ he2cbt(2) * f
      else
        do i=1,nhe2lvl+1
          he2lte(i) = 0.
        end do
      endif
*
*-----------------------------------------------------------------------
*     evaluate all needed collisional and rad rates
*     collisions turned off, HD=0
*----------------------------------------------------------------------
*
      if( lgHeClON ) then
        hd = 1.
      else
        hd = 0.
      endif
      ized = 2
*     collisional ionization
      if( lgCasBhs ) then
        he2clc(1) = 0.
        he2clc(2) = 0.
      else
*       call colfit(2,1,0,te,he2clc(1) )
*       >>chng 97 mar 28 to new data set
        call cfit(2,1,te,he2clc(1) )
        he2clc(1) = he2clc(1) * hd
        he2clc(2) = HydColIon(2,ized)
      endif
      do n=3,nhe2lvl
*       this routine can only go up to 20
        he2clc(n) = HydColIon(n,ized) * hd
      end do
*
*     don't reevaluate downward coll if dT/T not large
*     he2cll is zero on very first call since zeroed in block
      if( abs(te-told)/te .lt.0.002 .and. he2cll(2,1).gt.0.) then
         if( lgTrace.and.lgHeBug) write(qq,'(7x,
     1   ''HE2COL called-no reval Cul'')')
*        (but still eval col below)
      else
         if( lgTrace )write(qq,'(7X,''HE2COL called-will reeval Cul'')')
         told = te
*
         if ( lgC2psOn ) then
*          from Osterbrock's book, fit to 10,000K - 20,000K
*          he2c2p2s = 1.13e-3 / te10 / te10
*          >>chng 97 aug 2, to
*          >>refer Zygelman, B. & Dalgarno, A. 1987, Phys.Rev.A, 35, 4085
           he2c2p2se = 6.1279139e-07 + 15.686661e-07 *sexp(te/171410.98)
           he2c2p2sp = 83.61586e-07 + 85.907401e-07 * sexp(te/387913.43)
         else
           he2c2p2se = 0.
           he2c2p2sp = 0.
         endif
*
         tsq = te  * te
         t3 = tsq * te
*        collision strengths for 1-2S, 1-2P, and 1-3 from, Table A2
*        >>refer Hummer, D.E., & Storey, P.J. MNRAS, 224, 801
*        this is their defn of T4, expansion only good to 10^5 K
         t4 = te / 1e4
         t4 = min( 10., t4 )
*        CS12S = 0.1435 - 1.156E-3*T4 + 7.442E-5*T4*T4 -
*    1   6.725E-6*T4**3
*        CS12P = 0.2908 + 2.657E-2*T4 - 1.736E-3*T4*T4 +
*    2   7.498E-5 * T4**3
*        following Table 2 of
*        >>refer Aggarwal, K.M., Callaway, J., Kingston, A.E., Unnikrishnan,
*        >>refer K. 1992, ApJS, 80, 473
         call he2cs123( 1,2,te,cs12s )
         call he2cs123( 1,3,te,cs12p )
*
*        C1N is deexcitation rate
*        following is 2P - 1S only
         he2cll(2,1) = cs12p / sqrte * 8.629e-6 / 6. * hd
*        following is 2S - 1S only
         he2c2s1s = cs12s / sqrte * 8.629e-6 / 2. * hd
*
*        option to turn off collisions from ground and n=2
         if( lgCasBhs .or. (hd.eq.0.) ) then
           hsfac = 0.
         else
           hsfac = 1.
         endif
*
         call he2cs123( 1 , 4, te,cs13 )

*        HE2CLL(u,l) is de-excitation rate from u to l
         he2cll(3,1) = cs13/ sqrte * 8.629e-6/18. * hsfac
*
         call he2cs123( 2 , 4, te,cs2s3s )
         call he2cs123( 3 , 4, te,cs2p3s )
         cs23 = cs2s3s + cs2p3s
         he2cll(3,2) = cs23 / sqrte * 8.629e-6 / 18. * hsfac
*
*        following is ratio of he+ to h collisions for exact calc
         f = 0.7
         do ihi=4,nhe2lvl
           he2cll(ihi,1) = r1n(ihi) / sqrte * hsfac * f
*          different temp denpendence is not a bug
           he2cll(ihi,2) = r2n(ihi) * hsfac * f
           do lo=3,ihi-1
*            following to scale up to blaha
*            >>chng 96 june 5, factor to get better agreement with agrawall
             he2cll(ihi,lo) = HydColDwn(ihi,lo,ized) * hd
           end do
         end do
*
         if( lgTrace.and.lgHe2Bug ) then
           write(qq,'(7X,''HE2COL rate n->n-1:'',1P,8E10.3,'' 2S1'',
     1     e9.2)') (he2cll(i+1,i),i=1,8),he2c2s1s
           write(qq,'(7X,''HE2COL col ion cof:'',1P,9E10.3)') he2clc
           write(qq,'(7X,''HE2COL rate down 1:'',1P,9E10.3)') 
     1     (he2cll(i,1),i=1,9)
           write(qq,'(7X,''HE2COL rate down 2:'',1P,9E10.3)')
     1     (he2cll(i,2),i=1,9)
           write(qq,'(7X,''HE2COL rate down 3:'',1P,9E10.3)')
     1     (he2cll(i,3),i=1,9)
           write(qq,'(7X,''HE2COL rate down 4:'',1P,9E10.3)')
     1     (he2cll(i,4),i=1,9)
           write(qq,'(7X,''HE2COL rate down 5:'',1P,9E10.3)')
     1     (he2cll(i,5),i=1,9)
           write(qq,'(7X,''HE2COL boltz fac c:'',1P,9E10.3)') he2cbt
           write(qq,'(7X,''HE2COL HE2LTE(i):  '',1P,10E10.3)') he2lte
           write(qq,'(7X,''HE2COL       C2P2S='',1P,2e10.3)') he2c2p2se,
     1     he2c2p2sp
        endif
      endif
*
      if( he2lte(1).gt.0. ) then
*     following are eden independent, used in hlevel
      he2coldn(1) = (he2cll(2,1)*he2lte(2) + he2c2s1s*he2lte(10) +
     1     he2cll(3,1)*he2lte(3) + he2cll(4,1)*he2lte(4) +
     2 he2cll(5,1)*he2lte(5) + he2cll(6,1)*he2lte(6) +
     3 he2cll(7,1)*he2lte(7) + he2cll(8,1)*he2lte(8) +
     4 he2cll(9,1)*he2lte(9) ) / he2lte(1) 
*
*     SUM is total rate from high states to both 2s and 2p
      sum = (he2cll(3,2)*he2lte(3) + he2cll(4,2)*he2lte(4) +
     1 he2cll(5,2)*he2lte(5) + he2cll(6,2)*he2lte(6) +
     2 he2cll(7,2)*he2lte(7) + he2cll(8,2)*he2lte(8) + 
     3 he2cll(9,2)*he2lte(9) ) / ( he2lte(2) + he2lte(10) )
*
*     HE2CLL(2,1) is 2p - 1s rate; he2c2s1s is 2s - 1s rate
      he2coldn(2) = sum + he2cll(2,1)
      he2coldn(10) = sum + he2c2s1s
*
      he2coldn(3) = he2cll(3,1) + he2cll(3,2) + (he2cll(4,3)*he2lte(4) +
     1 he2cll(5,3)* he2lte(5) + he2cll(6,3)*he2lte(6) +
     2 he2cll(7,3)*he2lte(7) + he2cll(8,3)*he2lte(8) +
     3 he2cll(9,3) *he2lte(9) ) /he2lte(3)
*
      he2coldn(4) = he2cll(4,1) + he2cll(4,2) + he2cll(4,3) +
     1 (he2cll(5,4)*he2lte(5) + he2cll(6,4)*he2lte(6) +
     2 he2cll(7,4)*he2lte(7) + he2cll(8,4)*he2lte(8) +
     3 he2cll(9,4)*he2lte(9) ) / he2lte(4)
*
      he2coldn(5) = (he2cll(6,5)*he2lte(6) + he2cll(7,5)*he2lte(7) +
     1 he2cll(8,5)*he2lte(8) + he2cll(9,5)*he2lte(9)) /he2lte(5) +
     2 he2cll(5,1) + he2cll(5,2) + he2cll(5,3) + he2cll(5,4)
*
      he2coldn(6) = he2cll(6,1) + he2cll(6,2) + he2cll(6,3) +
     1 he2cll(6,4) +
     1 he2cll(6,5) + ( he2cll(7,6)*he2lte(7) + he2cll(8,6)*he2lte(8) +
     2 he2cll(9,6)*he2lte(9) ) /he2lte(6)
*
      he2coldn(7) = he2cll(7,1) + he2cll(7,2) + he2cll(7,3) +
     1 he2cll(7,4) +
     1 he2cll(7,5) + he2cll(7,6) + ( he2cll(8,7)*he2lte(8) +
     2 he2cll(9,7)*he2lte(9) ) /he2lte(7)
*
      he2coldn(8) = he2cll(8,1) + he2cll(8,2) + he2cll(8,3)+he2cll(8,4)
     1 + he2cll(8,5) + he2cll(8,6) + he2cll(8,7) +
     2 he2cll(9,8)*he2lte(9)/he2lte(8)
*
      he2coldn(9) = he2cll(9,1) + he2cll(9,2) + he2cll(9,3) +
     1 he2cll(9,4)
     1       + he2cll(9,5) + he2cll(9,6) + he2cll(9,7) + he2cll(9,8) 
*
      if( lgTrace.and.lgHe2Bug ) then
        write(qq,'(7X,''HE2CLL he2coldn(n)      '',1P,10E10.3)')
     1  (he2coldn(i),i=1,10)
        write(qq,'(7X,''HE2CLL he2radn(n)      '',1P,10E10.3)')
     1  (he2radn(i),i=1,10)
        write(qq,'(7X,''HE2CLL he2bul(n)      '',1P,10E10.3)')
     1  (he2bul(i),i=1,10)
      endif
      else
        do n=1,nhe2lvl
          he2coldn(n) = 0.
        end do
      endif
*
      end
