******************************************************************************
      subroutine he3col
      implicit none
*compute collisional rates for helium triplets
      include "nhe3lvl.par"
      include "he3bol.com"
      include "he3lte.com"
      include "edsqte.com"
      include "phycon.com"
      include "TePowers.com"
      include "he3c.com"
      include "che2sn.com"
      include "r2s3bd.com"
      include "trace.com"
      include "IOqq.com"
      include "hebug.com"
*
*     local variables
      real sexp , cs
*
*     edensqte = eden/sqrte
*     cdsqte = 8.629e-6*eden/sqrte
      if( lgTrace.and.lgHe3Bug ) write(qq,'('' HE3COL called.'')')
*
      he3bol(1) = sexp( 5.5298e4 / te )
      he3bol(2) = sexp( 4.2023e4 / te )
      he3bol(3) = sexp( 2.1676e4 / te )
      he3bol(4) = sexp( 1.8329e4 / te )
      he3bol(5) = sexp( 1.7558e4 / te )
*
*     all of following collision data from Berrington and Kingston '87
*     >>chng 97 july 25, updated to 
*     >>refer Sawey, P.M.J., and Berrington, K.A., 1993, ADNDT 55, 81
*
*     10830, 2 3S 2 3P
      cs = min(64.04 , 0.0186*te70*te10/te01 )
      c2p2s = cs * cdsqte / 9.
      c2s2p = c2p2s * 3. * he3bol(1)/max(1e-30,he3bol(2))
*
*     2 trip p to ground
      cs = min( 0.0364 , 4.322e-4 * sqrte/te05 / te02 )
      c2pg = cs * cdsqte / 9.
      csg2p = c2pg * 9. / 1. * sexp(2.4314e5/te)
*
*     2 trip s to ground
      c2sg = 8.428e-8 * edensqte * te10
      csg2s = c2sg * 3. / 1. * sexp(2.2986e5/te)
*
*     singlet 2s to triplet 2s
*
      if( te.gt.1e4 ) then
        cs = max(2.397 , 7.580/(te10*te02*te005) )
      else
        cs = min( 2.397 , 0.954 * te10 )
      endif
      cs2s2s = cs * cdsqte / 1.
*     trip 2s to singlet 2s
      c2ss2s =  cs2s2s*1./3. * sexp( 9234./te )

*     singlet 2p to trip 2s
      cs2p2s = 0.97 * cdsqte / 3.

*     trip 2s to singlet 2p
      cs = min( 1.15 , 0.245 * te10*te05 )
      c2ss2p = cs * cdsqte / 3. * sexp( 16219. /te )
*
*     2p to singlet 2s
      c2ps2s = 1.65 * cdsqte/9. 
      cs2s2p = c2ps2s*9./1. * sexp( 4041./te )
*
*     2p to singlet 2p
      cs2p2p =  4.4 * cdsqte/3.
      c2ps2p =  cs2p2p *3./9. * sexp(2945./te)
*
*     triplet 3s to 2s
      if( te.gt.1.5e4 ) then
        cs = min(2.63,0.561*te10*te05 )
      else
        cs = max( 2.79 , 5.121/(te10/te02 ) )
      endif
      c3s2s = cs * cdsqte / 3.
      c2s3s = c3s2s * he3bol(1)/max(1e-30,he3bol(3))
*
*     triplet 2s to 3p, 3889
      cs = min(1.88 , 1.0128*te03*te03 )
      c3p2s = cs * cdsqte / 9.
      c2s3p = c3p2s * 3. * he3bol(1)/max(1e-30,he3bol(4))
*
*     triplet 3d to 2s
      cs = min( 4.47 , 3.281e-3 * te70 )
      c3d2s = cs * cdsqte / 15.
      c2s3d = c3d2s * 5. * he3bol(1)/max(1e-30,he3bol(5))
*
*     triplet 3s 2p, 7065
      cs = min( 6.460 , 1.974*te10*te01*te005 )
      c3s2p = cs * cdsqte / 3.
      c2p3s = c3s2p / 3. * he3bol(2)/max(1e-30,he3bol(3))
*
*     triplet 3P -  2P
      cs = min( 11.45 , 0.4229*te30*te02 )
      c3p2p = cs * cdsqte / 9.
*     write(6,*) c3p2p
*     c3p2p = 1.58e-6/te10/te10/te10*te03 * eden
*     write(6,*) c3p2p
      c2p3p = c3p2p * he3bol(2)/max(1e-30,he3bol(4))
*
*     trip 3 3D to 2 3P, 5876
      cs = min( 22.19 , 1.117e-3 * te/te01/te01 )
      c3d2p = cs * cdsqte / 15.
      c2p3d = c3d2p * 1.67 * he3bol(2)/max(1e-30,he3bol(5))
*
*     HE3LTE is LTE density over (eden*next ion)
      if( he3bol(1).gt.0. ) then
         he3lte(1) =  3. / 2. * 2.0708e-16 / te32 / he3bol(1)
         he3lte(2) =  9. / 2. * 2.0708e-16 / te32 / he3bol(2)
      else
         he3lte(1) = 0.
         he3lte(2) = 0.
      endif
      if( he3bol(3).gt.0. ) then
         he3lte(3) =  3. / 2. * 2.0708e-16 / te32 / he3bol(3)
         he3lte(4) =  9. / 2. * 2.0708e-16 / te32 / he3bol(4)
         he3lte(5) =  15. / 2. * 2.0708e-16 / te32 / he3bol(5)
      else
         he3lte(3) = 0.
         he3lte(4) = 0.
         he3lte(5) = 0.
      endif
*
*     coll ioniz from 2.3.s from 
*     >>refer Seaton, M.S. 1964, Plan Sp Sci 12, 55.
      c2sion = 8.8e-10 * sqrte * eden * he3bol(1)
      c2pion = 3.*8.8e-10 * sqrte * eden * he3bol(2)
*     add three-body rec to recombination rates; units s^-1
      r2s3bd = c2sion * he3lte(1)
      r2p3bd = c2pion * he3lte(2)
*
      end
