******************************************************************************
      subroutine ionize
      implicit none
*main routine to drive ionization solution for all species
      include "ncell.par"
      include "nta.par"
      include "ipLnArry.par"
      include "nhlvl.par"
      include "limelm.par"
      include "itrdim.par"
      include "heating.com"
      include "DoPhoto.com"
      include "search.com"
      include "newion.com"
      include "efrac.com"
      include "iondun.com"
      include "toler.com"
      include "tseton.com"
      include "edsqte.com"
      include "x12.com"
      include "phlevl.com"
      include "logte.com"
      include "secmet.com"
      include "shullc.com"
      include "TePowers.com"
      include "tion.com"
      include "otsbug.com"
      include "trace.com"
      include "h.com"
      include "heat.com"
      include "phycon.com"
      include "cmeion.com"
      include "ots.com"
      include "hetmet.com"
      include "hmi.com"
      include "densty.com"
      include "he.com"
      include "collid.com"
      include "hgdist.com"
      include "totnuc.com"
      include "cspset.com"
      include "tcool.com"
      include "hem.com"
      include "erredn.com"
      include "rfield.com"
      include "IOqq.com"
      include "IonFracs.com"
      include "InCvgRsn.com"
      include "ntry.com"
      include "Trimed.com"
      include "ZoneCnt.com"
      include "iphl.com"
      include "SummdCon.com"
      include "chrex.com"
      include "TrueEden.com"
      include "TrConvg.com"
      include "LevTrace.com"
      include "nebug.com"
      include "HPhoto.com"
*
*     local variables
      integer nzSupra , ip
      save nzSupra
      real secsav , x12sav , hlax , sechi, seccmp, scmpla,factor,
     1 seche , helax , x12new , secnew , EdenProp , EdenOld,
     1 HeatOld ,damper , CorrBig , CorrSmall 
      save hlax , sechi , EdenOld , EdenProp, secnew, x12new,
     1 secsav , x12sav , CorrBig , CorrSmall
*     lgConverg is a function to check whether ionization has converged
      logical lgConverg , lgOK
*
*     these are the deltas for changes in the electron density
      data CorrSmall/0.35/ , CorrBig/2./
*
*     free statement numbers >= 7
*
*     update temperature variables which may have changed
      call tfidle
*
      alogne = log10( eden )
      tused = te
*
*-----------------------------------------------------------------------
*
*     NOCKON with effects of suprathermal electrons
*     nockon will evaluate ElecFrac
      call nockon
*
      if( lgTrace ) then
        write(qq,'(''   IONIZE called.  TE:'',1P,E9.3,''  HI:''
     1  ,E8.2,''  HII:'',E8.2,''  Ne:'',E9.3,''  CSUP:'',E8.2,
     1  ''  lgNewIon:'',L1,'' DoPhoto'',l1,''  ElecFrac:'',E9.2)')
     2  te, hi, hii,eden,csupra,lgNewIon,lgDoPhoto,ElecFrac
      end if
*
*     reevaluate gaunt factors and Boltzmann factors
      call boltgn
*
*     reevaluate all opacities if new ionization
*     >>chng 96 feb 29, see if this hurts
      if( lgDoPhoto ) call AddOpac(lgOK )
*     >>chng 96 may 16 turn back on
*     call AddOpac
*     update continuum
      call SumContinuum
*
*     hydrgn will set ionsun false if eden not converged
      call hydrgn( hlax , sechi )
*     nockon will update ElecFrac, sec efficiencies
      call nockon
*
*     electron density may have changed
      alogne = log10( eden )
*
*     evaluate Compton heating, bound E compton, cosmic rays
      call highen( seccmp , scmpla )
*
*     evaluate free-free heating rate
      call freeht
*
*     find corrections for three-body rec - collisional ionization
      call iiibod
*
      call helium( seche , helax )
*     this is only a sanity check
      call ChkSumCon(0)
*
*     find grain temperature, charge, and gas heating rate
      call grain
*
*-----------------------------------------------------------------------
*
*     these are sec ioniz, eval and incremented in BIDIAG, zero here
      secmet = 0.
      smetla = 0.
*     total cooling due to heavy element collisional ionization
      HeavIonCool = 0.
*
*     hetmet is total metal heating, will be incremented in BiDiag
*     which is called by each individual element
      hetmet = 0.
*
*     deduce dielctronic supression factors
      call DielSupres
*     fill in master charge transfer array
      call MakeCharTran
*     form sum of all continua
      call SumContinuum
*     this will be flag to check whether any ionization stages
*     were trimed down
      lgTrimed = .false.
*     zero out charge transfer rate array
      CTHion(1) = 0.
      CTHrec(1) = 0.
      chrener = 0.
*     do the ionization balance
      call lithi
      call beryli
      call boroni
      call carbon
      call oxygen
*     check whether oxygen ionization changed by much
      if( .not.lgConverg(8) ) then
        lgIonDone = .false.
        chInCvgRsn = 'Oxygen Ion'
      endif
      call codriv
      call nitrog
      call fluorinei
      call neon
      call sodium
      call magnes
      call alumin
      call silicn
      call phosi
      call sulphr
      call clrine
      call argoni
      calL potasi
      call calcm
      call scandi
      call titani
      call vanai
      call chromi
      call mangi
      call iron
*     >>chng 96 oct 11, added following test
*     check whether iron ionization changed by much
      if( .not.lgConverg(26) ) then
        lgIonDone = .false.
        chInCvgRsn = 'Iron Ioniz'
      endif
      call cobalt
      call nickel
      call coppi
      call zinci
*
*     turn photoionization rate evaluation if trimed down
      if( lgTrimed ) then
        lgDoPhoto = .true.
*       write(qq,'('' lgdophoto true ionize trim'')')
        lgNewIon = .true.
      endif
*
*     option to print OTS continuum with TRACE OTS
      if( lgTrace.and.lgOTSBug ) then
        call otsbg
      endif
*
*----------------------------------------------------------------------
*
*     update electron density 
      EdenOld = eden
*     routine ESUM sets variable EdenTrue to true elec den
      call esum
*
*     following block is to not let electron density change by
*     too much
*     EdenError is set in block data, constant allowed error
*     the default value of EdenError is 0.01 in block data
*     EdenOld was incoming value of eden
*     EdenTrue is correct value from esum for current ionization
*     eden will be set using these, trying to prevent oscillations
      if( abs(EdenOld-EdenTrue)/min(EdenOld,EdenTrue).ge.EdenError) then
*       changed by too much, lets do it again
        lgIonDone = .false.
        chInCvgRsn = 'Ne big chg'
*       SEARCH is TRUE if this is only search for first solution
        if( lgSearch ) then
          if( lgTrConvg .and.nLevTrace.lt.2 ) then
            write(qq,'(5x,''ionize, chg1 ne from, to, dn'',1p,3e10.3)')
     1      EdenOld, 10.**( (log10(EdenOld) + log10(EdenTrue) ) / 2. )
          endif
          eden = 10.**( (log10(EdenOld) + log10(EdenTrue) ) / 2. )
        else
*
*         this is the proposed new electron density - is it too different?
          EdenProp = 10.**( (log10(EdenOld) + log10(EdenTrue) ) / 2. )
          EdenProp = EdenTrue
*
*         derive correction factor - how far from the solution are we?
          if( abs(1.-EdenTrue/EdenOld).gt.EdenError*CorrBig ) then
            factor = 1. + EdenError * CorrBig
          else
*           this will be a small change
            factor = 1. + EdenError * CorrSmall
          endif
*
*         get the new electron density
          if( EdenProp/EdenOld.gt.(1.+EdenError*0.5 ) ) then
*           this branch, proposed eden too big
            eden = min( EdenProp , EdenOld * factor )
            ip = 1
          else if( EdenProp/EdenOld.lt.(1.-EdenError*0.5) ) then
*           proposed eden too small
            eden = max( EdenProp , EdenOld / factor )
            ip = 2
          else
*           eden was within fac of the correct value, use it
            eden = EdenProp
            ip = 3
          endif
          if( (lgTrConvg.and.nLevTrace.lt.2).or.(lgTrace.and.lgNeBug))
     1      then
            write(qq,'(5x,''IONIZE, chg'',i1,'' ne to'',1p,e10.3,
     1      '' EdenOld'',e10.3,'' ratio'',e10.3,'' EdenProp'',e10.3,
     2      '' true='',e10.3)')
     1      ip, eden,  EdenOld, eden/EdenOld , EdenProp, EdenTrue
          endif
        endif
        if( eden.le.0. ) then
          write(qq,'('' Negative electron density in IONIZE.'')')
          call ShowMe
          stop
        endif
*       if( lgTrace)write(qq,'(''   IONIZE will not let Ne change by'',
*    1  '' too much, new Ne='',1P,E11.4,'' old was='',E11.4,
*    2  '' correct (computed in ESUM) is'',E11.4)') eden, EdenOld ,
*    3  EdenTrue
*       update temperature variables which may have changed
*       >>chng 96 oct 25 update eden related variables now
        call tfidle
      endif
*
*     get total heating rate
      HeatOld = htot
      call SumHeat
      if( HeatOld.gt.0. .and. .not.lgTSetOn ) then
*       check if heating has converged - toler is final match
        if( abs(1.-htot/HeatOld) .gt.toler*.5 ) then
          lgIonDone = .false.
          chInCvgRsn = 'Big d Heat'
        endif
      endif
*
*     find total suprathermal collisional ionization rate
*     CSUPRA is col ionize rate from all processes (inv sec)
*     X12 is LA excit rate, inv sec
*     SECCMP evaluated in HIGHEN, =ioniz rate for cosmic rays, sec bound
      if( nzone.lt.1 ) then
        nzSupra = -1
        secsav = csupra
        x12sav = x12
      endif
*     option to force secondary ionization rate, normally false
      if( lgCSetOn ) then
        csupra = SetCsupra
        x12 = SetCsupra
      else
*       >>chng 96 oct 29, eval continuously to stop oscillation between
*       two states deep in x-ray illuminated clouds
*     else if( nzone.ne.nzSupra ) then
*       each of following defined per unit neutral, except for SECMET
*       which is already mult by density of heavies
*       seche is set in helium and has densities
        secnew = seccmp + sechi*(hi+2.*htwo) + seche + secmet
*       CollidDensity is total neutral particle density
        secnew = secnew /  CollidDensity
        secnew = max( 0.,secnew )
*
        damper = 0.3
*       >>chng 96 may 13, try to damp out oscillations
        nzSupra = nzone
        nzSupra = -1
        csupra = secnew * damper + secsav*(1.-damper)
        secsav = csupra
*       now do same for Ly-alpha
        x12new = (scmpla + hlax*(hi+2.*htwo) +
     1   helax + smetla) / CollidDensity
           x12 = x12new * damper + x12sav*(1.-damper)
        x12sav = x12
      endif
*
      if( lgTrace .and. csupra.gt.0. ) then
        if( secnew.gt.0. ) then
          write(qq,'(''   IONIZE, CSUPRA='',1P,E10.3,'' fracHI'',
     1    E9.2,'' He'',E9.2,'' met'',E9.2,'' com'',E9.2,
     1    '' sec/H-phot'',E9.2,'' X12/COL12'',E9.2)')
     1    csupra ,
     2    sechi * (hi+2.*htwo)/CollidDensity /secnew ,
     3    seche/CollidDensity /secnew ,
     4    secmet/CollidDensity /secnew ,
     5    seccmp /CollidDensity /secnew ,
     6    csupra/max(1e-34,hgamnc(1)) , x12/max(1e-34,hgdist)
        else
          write(qq,'(''   IONIZE, CSUPRA, SECNEW was zero.'')')
        endif
      endif
*
      if( lgTrace .and. csupra.ne.0. ) then
         write(qq,'(''   IONIZE retrn CSUPRA'',1P,E9.2,'' SECCMP'',E9.2,
     1  '' SECHI'',E9.2,'' SECHE'',E9.2,'' SECMET'',E9.2,'' SECSAV'',
     2  E9.2,'' X12'',E9.2)') csupra,seccmp,sechi,seche,secmet,secsav,
     3  x12
*
      else if( lgTrace ) then
        write(qq,'(''   IONIZE retrn, HI:'',1P,E10.3,''  HII:'',
     1  E10.3,''  EDEN:'',E10.3,'' HTOT:'',e10.3,'' lgIonDone='',L3)')
     1  hi, hii, eden,htot,lgIonDone
      endif
*
      end
