******************************************************************************
      subroutine LevelN(nlev,ndim,abund,g,ex,p,data,dest,pump,ipdest,
     1 cooltl, coolder, chLabel,lgNegPop)
      implicit none
*compute an arbitrary N level atom
      logical lgNegPop
*     nlev is the number of levels to compute, ndim is dimension of array
      integer nlev , ndim
      real cooltl , abund , coolder
      real g(ndim) , p(ndim) , ex(ndim) , data(ndim,ndim)
      real dest(ndim,ndim), pump(ndim,ndim)
      integer ipdest(ndim,ndim)
      character chLabel*4
*
      include "bltzman.par"
      include "limLevelN.par"
      include "TePowers.com"
      include "PopLevls.com"
      include "edsqte.com"
      include "phycon.com"
      include "dcool.com"
      include "called.com"
      include "TrLevN.com"
      include "trace.com"
      include "IOqq.com"
*
*     local variables
      double precision zz(limLevelN,limLevelN) 
      real excit(limLevelN,limLevelN) , crate(limLevelN,limLevelN)
*
      integer ihi , ilo , i  , j , ner
      real sexp , ots , cool1
*
*     PARAMETER statement:
*     limLevelN is upper limit to number of levels allowed by present dim
*
*     entering variables
*     NLEV is number of present dimensions
*     ABUND is total abundance of species, used for nth equation
*     G(ndim) is stat weight of levels
*     EX(ndim) is excitation potential of levels, deg K
*       0 for first one, NOT d(ENER), but energy rel to ground
*     DATA(ihi,ilo) is transit prob from up to low
*     DATA(ilo,ihi) is col str from up to low
*     lgNegPop is true is negative populations occurred
*
*     deduced variables
*     EXCIT(IHI,ILO) excitation Boltzman factor
*     CRATE(IHI,ILO) collis deexcit rate
*     CRATE(ILO,IHI) collis excit rate
*
*     free statements >=20
*
*     check if too many levels used
*     >>chng 96 aug 22, had been .gt., off by one at limit since z(n,n+1) used
      if( ndim.ge.limLevelN ) then
        write(qq,'('' LevelN called with too many levels, the limit is''
     1  ,I5)') limLevelN
        stop
      endif
*
*begin sanity checks
*     excitation temperature of lowest level must be zero
      if( ex(1).ne.0. ) then
        write(qq,'('' LevelN called with non-zero ex(1)'')')
        stop
      endif
*     both dest and pump (low, hi) are not used, should be zero
      do ihi=2,nlev
        do ilo=1,ihi-1
*         zero ots destruction rate
          if( dest(ilo,ihi).ne.0. ) then
            write(qq,'('' LevelN called with non-zero dest(l,u)'')')
          endif
          if( pump(ilo,ihi).ne.0. ) then
            write(qq,'('' LevelN called with non-zero pump(l,u)'')')
          endif
          if( ipdest(ilo,ihi).ne.0 ) then
            write(qq,'('' LevelN called with non-zero ipdest(l,u)'')')
          endif
        end do
      end do
*     data(i,i) should be zero
      do ihi=1,nlev
        if( data(ihi,ihi).ne.0 ) then
          write(qq,'('' LevelN called with non-zero data(i,i)'')')
        endif
      end do
*end sanity checks
*
      if( lgTrace.and.lgTrLevN ) then
        write(qq,'('' dest'')')
        write(qq,'(''  hi  lo'',10(i4,6x))') (ilo,ilo=1,nlev)
        do ihi=1,nlev
          write(qq,'(i3,1p,10e10.2)') ihi,(dest(ihi,ilo),ilo=1,nlev)
        end do
        write(qq,'('' data'')')
        write(qq,'(''  hi  lo'',10(i4,6x))') (ilo,ilo=1,nlev)
        do ihi=1,nlev
          write(qq,'(i3,1p,10e10.2)') ihi,(data(ihi,ilo),ilo=1,nlev)
        end do
        write(qq,'('' pump'')')
        write(qq,'(''  hi  lo'',10(i4,6x))') (ilo,ilo=1,nlev)
        do ihi=1,nlev
          write(qq,'(i3,1p,10e10.2)') ihi,(pump(ihi,ilo),ilo=1,nlev)
        end do
      endif
*
      do ihi=2,nlev
        do ilo=1,ihi-1
*         zero ots destruction rate
          if( ipdest(ihi,ilo).gt.0 ) then
            call AddOTSLin( 0.,ipdest(ihi,ilo) ,1.0 )
          endif
        end do
      end do
*
*     check for zero abundance and exit if so
      if( abund.le.0. ) then
        cooltl = 0.
        coolder = 0.
        lgNegPop = .false.
        do i=1,nlev
          p(i) = 0.
*         these are off by one - lowest index is zero
          PopLevels(i-1) = 0.
          DepLTELevels(i-1) = 0.
        end do
        PopLevels(0) = abund
        DepLTELevels(0) = 1.
*       there are TWO abort returns in this sub
        return
      endif
*
      do ilo=1,nlev-1
        do ihi=ilo+1,nlev
          excit(ihi,ilo) = sexp( (ex(ihi) - ex(ilo)) / te )
        end do
      end do
      if( lgTrace.and.lgTrLevN ) then
        write(qq,'('' excit, te='',1p,e10.2)') te
        write(qq,'(''  hi  lo'',10(i4,6x))') (ilo,ilo=1,nlev)
        do ihi=1,nlev
          write(qq,'(i3,1p,10e10.2)') ihi,(excit(ihi,ilo),ilo=1,nlev)
        end do
      endif
*
*     punt if total excitation rate is zero
      if( excit(nlev,1)+pump(nlev,1).lt.1e-13 ) then
        cooltl = 0.
        coolder = 0.
        lgNegPop = .false.
        do i=2,nlev
          p(i) = 0.
*         these are off by one - lowest index is zero
          PopLevels(i-1) = 0.
          DepLTELevels(i-1) = 0.
        end do
*       everything in ground
        p(1) = abund
        PopLevels(0) = abund
        DepLTELevels(0) = 1.
        return
      endif
*
*     factor is 8.629E-6 / SQRTE * EDEN
      do ilo=1,nlev-1
        do ihi=ilo+1,nlev
*         this is deexcitation rate
*         factor is 8.629E-6 / SQRTE * EDEN
          crate(ihi,ilo) = data(ilo,ihi)/g(ihi) * cdsqte
*         this is excitation rate
          crate(ilo,ihi) = crate(ihi,ilo) * g(ihi)/g(ilo) *
     1    excit(ihi,ilo)
        end do
      end do
*
*     rate equations equal zero
      do i=1,nlev
        do j=2,nlev
*       do j=1,nlev-1
          zz(j,i) = 0.
        end do
*       zz(nlev,i) = 1.0
        zz(1,i) = 1.0
      end do
*
*     following is colum of vector
      do i=1,nlev
        zz(i,nlev+1) = 0.
      end do
*     zz(nlev,nlev+1) = abund
*     solve the problem with everything normalzied to pop of unity
*     for numerical stbility
*     zz(nlev,nlev+1) = 1.
      zz(1,nlev+1) = 1.
*
*     eqns for destruction of level
*     data(hi,lo) are A's, crate is coll excit in direction
*     doi=1,nlev-1
      do i=2,nlev
        zz(i,i) = 0.
*       leaving I to below
        do ilo=1,i-1
          zz(i,i) = zz(i,i) + crate(i,ilo) + data(i,ilo) +
     1    dest(i,ilo)
     2    + pump(i,ilo) * g(ilo)/g(i)
*         >>chng 97 jul 31, added pumping down
*         coming to level I from below
          zz(i,ilo) = -crate(ilo,i) - pump(i,ilo)
        end do
        do ihi=i+1,nlev
*         leaving I to above
          zz(i,i) = zz(i,i) + crate(i,ihi) + pump(ihi,i)
*         coming to level I from above
          zz(i,ihi) = -crate(ihi,i) - data(ihi,i) - dest(ihi,i)
     2    - pump(ihi,i) * g(i)/g(ihi)
*         >>chng 97 jul 31, added pumping down
        end do
      end do
*
      call matin1( zz,limLevelN,nlev,1,ner)
      if( ner.ne.0 ) then
        if( lgTalk ) write(qq,'('' LevelN MATRIX ERROR.'')')
        stop
      endif
*
*     set populations
      do i=1,nlev
*       convert to real abundances
        p(i) = zz(i,nlev+1) * abund
      end do
*
*     now find total cooling and its derivative
      cooltl = 0.
      coolder = 0.
      do ihi=2,nlev
        do ilo=1,ihi-1
*         this is net cooling in oK
          cool1 = (p(ilo)*crate(ilo,ihi)-p(ihi)*crate(ihi,ilo)) *
     2    ( ex(ihi)-ex(ilo) )
          cooltl = cooltl + cool1
*         simplistic way to handle line heating - better would
*         be to go  over to method in level2 and level3
          coolder = coolder + 
     1    max(0.,cool1) * ( (ex(ihi)-ex(1))*tsq1-halfte)
        end do
      end do
*     convert to ergs
      cooltl = cooltl * Boltzmann
      coolder = coolder * Boltzmann
*
*     fill in departure coefficients
      if( p(1).gt.1e-20 .and. excit(nlev,1).gt.1e-20 ) then
        do ihi=2,nlev
*         these are off by one - lowest index is zero
          PopLevels(ihi-1) = p(ihi)
          DepLTELevels(ihi-1) = (p(ihi)/p(1))*(g(1)/g(ihi))/excit(ihi,1)
        end do
      else
        do ihi=2,nlev
*         these are off by one - lowest index is zero
          PopLevels(ihi-1) = 0.
          DepLTELevels(ihi-1) = 0.
        end do
      endif
      PopLevels(0) = abund
      DepLTELevels(0) = 1.
*
*     in case atom has been trimed down
      do i=nlev+1,ndim
        p(i) = 0.
        PopLevels(i-1) = 0.
        DepLTELevels(i-1) = 0.
      end do
*
*     sanity check for stability of inversion
      lgNegPop = .false.
      do i=1,nlev
        if( p(i).lt.0. ) then
          lgNegPop = .true.
        endif
      end do
      if(lgNegPop) then
        write(qq,'('' LevelN found negative population, atom='',a4)
     1   ') chLabel
        write(qq,'('' absolute population='',1p,1p,10e10.2)') 
     2  (p(i),i=1,nlev)
        do i=1,nlev
          p(i) = max(0.,p(i) )
        end do
      endif
*
      do ihi=2,nlev
        do ilo=1,ihi-1
*         set ots destruction rate
          if( ipdest(ihi,ilo).gt.0 ) then
            ots = p(ihi) * dest(ihi,ilo)
            call AddOTSLin( ots,ipdest(ihi,ilo) ,1.0 )
          endif
        end do
      end do
*
      end
