******************************************************************************
      subroutine p8446( coloi )
      implicit none
*drive the solution of OI level populations, Ly-beta pumping
      real coloi
      include "ncell.par"
      include "ipLnArry.par"
      include "limelm.par"
      include "nhlvl.par"
      include "nta.par"
      include "itrdim.par"
      include "htnext.com"
      include "radius.com"
      include "IterCnt.com"
      include "ZoneCnt.com"
      include "htau.com"
      include "hesc.com"
      include "rfield.com"
      include "widflx.com"
      include "phycon.com"
      include "TePowers.com"
      include "fluors.com"
      include "h.com"
      include "DoppVel.com"
      include "phlevl.com"
      include "bowoi.com"
      include "tr8446.com"
      include "trace.com"
      include "escdst.com"
      include "TLineEXP.com"
      include "popoi.com"
      include "touton.com"
      include "IonFracs.com"
      include "IOqq.com"
*
*     local variables
      integer i
      real aoi,alb,tin,tout,esin,esccom,esab,esoi,
     1 eslb,opacoi,opaclb,foi,flb,xlb,xoi,pmph13
      save esab
*
*     free statement labels >=2
*
*     A's from Pradhan; OI pump line; Ly beta, 8446
      data aoi/7.24e7/ , alb/5.575e7/
*
*     Notation;
*     PMPH31 net rate hydrogen level 3 depopulated to 1
*     PMPO15 and PMPO51 are similar, but for oxygen
*     ESCH31 is emission in 1025 transition
*
*     called by LINES before calc really start, protect here
*     also used for cases where OI not present
      if( xIonFracs(8,1).le.0.) then
        do i=1,6
          popoi(i) = 0.
        end do
        coloi = 0.
        pmpo15 = 0.
        pmpo51 = 0.
*       3,1 is escape prob, 1,3 is product with a
        pmph31 = hesc(1,3)
        esch31 = hesc(1,3)
        if( lgTr8446.and.lgTrace ) then
          write(qq,'(7X,''P8446 called for first ''
     1    ,''time, finds 3-1 escape prob='',1P,E10.2)') hesc(1,3)
        end if
        return
      endif
*
      if( lgTauOutOn ) then
*       two sided escape prob
        tin = htnext(3,1)+tO1025(ipLnTauIn) 
        esin = esccom( tin ,1e-4 )
        tout = (htlim(3,1)+tO1025(ipLnTauTot))*0.9 -
     1  htnext(3,1)-tO1025(ipLnTauIn)
        if( tout.gt.0. ) then
          tout = htlim(3,1)+tO1025(2)-htnext(3,1)-tO1025(1) 
*         do not update esab if we overran optical depth scale
          esab = 0.5 * ( esin + esccom( tout ,1e-4 ) )
        endif
      else
*       one-sided escape probability
        esab = esccom( htnext(3,1)+tO1025(1) ,1e-4 )
      endif
*
      esoi = tO1025(ipLnEscP)
      eslb = hesc(3,1)
*
      if( lgTr8446.and.lgTrace ) then
        write(qq,'(7X,''P8446 finds Lbeta, OI '',
     1  ''widths='',1P,2E10.2,'' and esc prob='',2E10.2,'' esAB='',
     2  e10.2)') doppler(1), doppler(8), eslb, esoi, esab
      endif
*
*     find relative opacities for two lines
      opacoi = 2.92e-9 * xIonFracs(8,1) * 0.5556 / doppler(8)
      opaclb = 1.22e-8 * hii*hn(1) / doppler(1)
*     these are x sub a (OI) and x sub b (ly beta) defined in Elitz+Netz
      xoi = opacoi / ( opacoi + opaclb )
      xlb = opaclb / ( opacoi + opaclb )
*
*     find relative line-widths, assume same rest freq
      foi = min( doppler(1) , doppler(8) ) / doppler(8)
      flb = min( doppler(1) , doppler(8) ) / doppler(1) *
     1  (1. - tO1025(ipLnEscP) )
      if( lgTr8446.and.lgTrace ) write(qq,'(7X,''P8446 opac Lb, OI='',
     1 1P,2E10.2,'' X Lb, OI='',2E10.2,'' FLb, OI='',2E10.2)')
     2 opaclb,opacoi, xlb,xoi, flb, foi
*
*     pumping of OI by L-beta - this goes into OI matrix as 1-5 rate
*     lgFluor set false with no induced command, usually true
      if( lgFluor ) then
        pmpo15 = flb * alb * (hn(3)*hii) * xoi * (1. - esab )/
     1  xIonFracs(8,1)
*       net decay rate from upper level
        pmpo51 = aoi * ( 1.-(1.-foi)*(1.-esoi) - xoi*(1.-esab)*foi )
      else
        pmpo15 = 0.
        pmpo51 = 0.
      endif
*
*     find level populations for OI
      call oilevl( xIonFracs(8,1) , coloi )
*
*     escape term from n=3 of H; followed by pump term to n=3
      pmph31 = alb * ( 1.-(1.-flb)*(1.-eslb) - xlb*(1.-esab)*flb )
      pmph13 = xlb * (1.-esab ) * foi * aoi * popoi(5)
      pmph31 = hesc(1,3)
*
*     following is actual emission rate, used to predict Ly-beta in lines.for
      esch31 = alb * ( eslb * (1.-flb) + esab*flb )
      if( lgTr8446.and.lgTrace ) write(qq,'(7X,''P8446 PMPH31='',1P,
     1E10.2,'' EscP3-1'',E10.2,'' ESCH31='',E10.2)') 
     2 pmph31,pmph31/alb,esch31/alb
*
*     continuum pumping due to J=1, 0 sub states.
*     neglect J=2 since L-Beta very optically thick
*
*     lower level populations
      t1304(ipLnPopl) = popoi(1)
      tO1025(ipLnPopl) = popoi(1)
      t1039(ipLnPopl) = popoi(1)
      t8446(ipLnPopl) = popoi(2)
      t4368(ipLnPopl) = popoi(2)
      tOI13(ipLnPopl) = popoi(3)
      tOI11(ipLnPopl) = popoi(3)
      tOI29(ipLnPopl) = popoi(4)
      tOI46(ipLnPopl) = popoi(5)
*
*     upper level populations
      t1304(ipLnPopu) = popoi(2)
      tO1025(ipLnPopu) = popoi(5)
      t1039(ipLnPopu) = popoi(4)
      t8446(ipLnPopu) = popoi(3)
      t4368(ipLnPopu) = popoi(6)
      tOI13(ipLnPopu) = popoi(4)
      tOI11(ipLnPopu) = popoi(5)
      tOI29(ipLnPopu) = popoi(6)
      tOI46(ipLnPopu) = popoi(6)
*
*     opacity factor
*     t1304(ipLnPopOpc) = (popoi(1)-popoi(2)*3.0)
* 666 error! following needed to get badbugs/bug8.in to work
      t1304(ipLnPopOpc) = popoi(1)
      tO1025(ipLnPopOpc) = (popoi(1)-popoi(5)*0.6)
      t1039(ipLnPopOpc) = (popoi(1)-popoi(4)*3.0)
*     t8446(ipLnPopOpc) = (popoi(2)-popoi(3)*.33)
* 666 error! following needed to get badbugs/bug5.in to work
      t8446(ipLnPopOpc) = max(0., popoi(2)-popoi(3)*.33)
      t4368(ipLnPopOpc) = (popoi(2)-popoi(6)*.33)
      tOI13(ipLnPopOpc) = (popoi(3)-popoi(4)*3.0)
      tOI11(ipLnPopOpc) = (popoi(3)-popoi(5)*0.6)
      tOI29(ipLnPopOpc) = (popoi(4)-popoi(6)*.33)
      tOI46(ipLnPopOpc) = (popoi(5)-popoi(6)*1.67)
*
      call AddOTSLin( popoi(2)*t1304(ipLnDesP)*t1304(ipLnAul),
     1 int(t1304(ipLnIpCont)) ,0.1)
*     call AddOTSLin( popoi(4)*t1039(ipLnDesP)*t1039(ipLnAul),
*    1 int(t1039(ipLnIpCont)) ,0.5)
      call AddOTSLin( popoi(3)*t8446(ipLnDesP)*t8446(ipLnAul),
     1 int(t8446(ipLnIpCont)) ,0.5)
      call AddOTSLin( popoi(6)*t4368(ipLnDesP)*t4368(ipLnAul),
     1 int(t4368(ipLnIpCont)) ,0.5)
      call AddOTSLin( popoi(4)*tOI13(ipLnDesP)*tOI13(ipLnAul),
     1 int(tOI13(ipLnIpCont)) ,0.5)
      call AddOTSLin( popoi(5)*tOI11(ipLnDesP)*tOI11(ipLnAul),
     1 int(tOI11(ipLnIpCont)) ,0.5)
      call AddOTSLin( popoi(6)*tOI29(ipLnDesP)*tOI29(ipLnAul),
     1 int(tOI29(ipLnIpCont)) ,0.5)
      call AddOTSLin( popoi(6)*tOI46(ipLnDesP)*tOI46(ipLnAul),
     1 int(tOI46(ipLnIpCont)) ,0.5)
*
      end
