******************************************************************************
      subroutine punt(chType)
      implicit none
*produce map of heating-cooling space for specified zone
      character chType*4
*
      include "itrdim.par"
      include "ncolnt.par"
      include "mapdim.par"
      include "limelm.par"
      include "MapPar.com"
      include "cnegtk.com"
      include "heating.com"
      include "telow.com"
      include "TePowers.com"
      include "he.com"
      include "thigh.com"
      include "called.com"
      include "tion.com"
      include "heat.com"
      include "phycon.com"
      include "collab.com"
      include "ZoneCnt.com"
      include "coolnt.com"
      include "h.com"
      include "tcool.com"
      include "newion.com"
      include "mapr.com"
      include "trace.com"
      include "IOqq.com"
*
*     local variables
      character*4 chLabel , units*1
      real eps,t1,torg,xx,TotalPressure,ratio,fac,factor,tmax,tmin,
     1 tlowst,oldch,dc,strong,strhet,ch,hfrac,cfrac
      integer k,j,ih,jh,l
      integer i , loop
      parameter (eps=0.005)
*
*     free statement labels >=6
*
      t1 = te
      torg = te 
*     make sure pressure has been evaluated
      xx = TotalPressure()
*
*     print out all coolants if all else fails
      if( lgTalk ) then
        write(qq,'('' Cloudy punts, Te='',1P,E10.3,'' HTOT='',E10.3,
     1  '' CTOT='',E10.3,'' nzone='',i4)') te , htot , ctot,nzone
        write(qq,'('' COOLNG array is'')')
*
        if( ctot.gt.0. )  then
          call coolpr( 'ZERO' ,1,  0. , eps )
          do i=1,ncltot
            ratio = cooling(i) / ctot
            call coolpr( chClntLab(i) , collam(i), ratio , eps )
          end do
          call coolpr( 'DONE', 1 , 0. , eps )
          write(qq,'('' Line heating array follows'')')
          call coolpr( 'ZERO' ,1,  0. , eps )
          do i=1,ncltot
            ratio = heatnt(i) / ctot
            call coolpr( chClntLab(i) , collam(i), ratio , eps )
          end do
          call coolpr( 'DONE', 1 , 0. , eps )
        endif
      endif
*
*     map out te-ionization-cooling space before punching out.
      if( lgTalk ) then
        write(qq,'(4X,''Te'',5X,''Heat'',19(''-''),''> Cool'',
     1  22(''-''),''>'',4x,''dH/dT'',4X,''dC/DT'',4X,
     1  3X,''Ne'',9X,''NH'',6X,''HII'',7X,''Helium '')')
      endif
*
      if( chType.eq.'punt') then
*       this is the original use of punt, we are punting
*       only map within factor of two of final temperature
*       fac will the range to either side of punted temperature
        fac = 1.5
        tmin = torg / fac
        tmax = torg * fac
*       we want about 20 steps between high and low temperature
*       default of nMapStep is 20, set with set nmaps command
        factor = 10.**(log10(tmax/tmin)/float(nMapStep) )
        te = tmin
      else if( chType.eq.' map' ) then
*       create some sort of map of heating-cooling
        tlowst = max( RangeMap(1) , telow)
        tmin = tlowst * 0.998
        tmax = min( RangeMap(2) , tehigh ) * 1.002
*       we want about nMapStep (=20) steps between high and low temperature
        factor = 10.**(log10(tmax/tmin)/float(nMapStep))
        if( lgTeHigh ) then
*         high te
          factor = 1. / factor
*         TEHIGH is highest possible temperature, 1E10
          te = min( RangeMap(2) , tehigh ) / factor
        else
*         low te
          te = tlowst / factor
        endif
      else
*       don't know what to do
        write(qq,'('' PUNT called with insane argument,='',A4)') chType
        stop
      endif
*
      lgCNegChk = .false.
      nmap = 0
      oldch = 0.
      te = te * factor
      do while( te.lt.tmax*0.999 .and. te.gt.tmin*1.001 )
        nmap = min( mapdim , nmap + 1 )
        xx = TotalPressure()
        call nsset
        lgNewIon = .true.
        call cholup( dc , loop )
        temap(nmap) = te
        cmap(nmap) = ctot
        hmap(nmap) = htot
        strong = 0.
        do j=1,ncltot
          if( cooling(j) .gt. strong ) then
            chLabel = chClntLab(j)
            strong = cooling(j)
            l = collam(j)
          endif
        end do
        cfrac = strong / ctot
        strhet = 0.
        do k=1,limelm
          do j=1,limelm
            if( heating(k,j).gt.strhet ) then
              strhet = heating(k,j)
              ih = k
              jh = j
            endif
          end do
        end do
        ch = ctot - htot
*       use ratio to check for change of sign since product
*       can underflow at low densities
        if( oldch/ch.lt.0..and. lgTalk ) then
          write(qq,'(1X,47(''-''),'' Probable thermal solution'',
     1    '' here. '',44(''-''))')
        endif
        oldch = ch
        hfrac = strhet / htot
        if( lgTalk ) then
*         convert to micros if IR transition
          if( l.lt.100 000. ) then
            units = 'A'
          else
            l = l / 1e4
            units = 'm'
          endif
          if( lgTrace )write(qq,'(''TRACE: te, htot, ctot'',1p,3e11.3)')
     1    te,htot,ctot
          write(qq,'(1P,e10.4,E11.4,2I4,0P,F6.3,1P,E11.4,1X,A4,1X,I4,a1,
     1    0P, F6.3,1P,2e10.2,2E11.4,0P,4F6.2)')
     1    te,htot,ih,jh,hfrac,ctot,chLabel,l,units,cfrac,dHTotDT,dc,
     1    eden, hden,log10(max(1e-9,hii/hden)) ,
     1    log10(max(1e-9,hei/ahe)),
     1    log10(max(1e-9,heii/ahe)),log10(max(1e-9,heiii/ahe))
        endif
        te = te * factor
      end do
*
      lgCNegChk = .true.
      te = t1
*
      end
