******************************************************************************
      subroutine silcol
      implicit none
*compute silicon cooling
      include "ndfst.par"
      include "limLevelN.par"
      include "ipLnArry.par"
      include "limelm.par"
      include "nta.par"
      include "dcool.com"
      include "coolsi.com"
      include "TLineEXP.com"
      include "TePowers.com"
      include "p2ovp1.com"
      include "phycon.com"
      include "PopLevls.com"
      include "h.com"
      include "edsqte.com"
      include "TauDmmy.com"
      include "IonFracs.com"
      include "embesq.com"
*
*     local variables
      real cs,p2,expion,popexc,
     1 cs2s2p,cs2s3p,pop3 , cs01,cs02,cs12
*
*     Si I 2518
      call MakeCS( Sii2518 )
      call level2( Sii2518 )
*
*     Si I 2215
      call MakeCS( Sii2215 )
      call level2( Sii2215 )
*
*     Silicon II 35 micron; elec cs from 
*     >>refer Dufton, P.L., & Kingston, A.E. 1994, ADNDT, 57, xx
      cs = 5.77
*     hydrogen collision strength from 
*     >>refer Tielens, A.G.G., & Hollenbach, D. 1985, ApJ, 291, 722
*     they give rate de-ex 6.5E-10 cm^3 s^-1, indep of temp
      cs = cs + 6.5e-10 / cdsqte * 4. * hi
      call PutCS( cs , tSi35 )
      call level2( tSi35 )
*
*     Si II  2337, atomic data from 
*     >>refer Dumont, A.M., & Mathez, G. 1981, A&A, 102, 1
*     coll str 
*     >>refer Dufton, P.L., & Kingston, A.E. 1991, MNRAS, 248, 827
*     also 
*     >>refer Mendoza, C. 1982, in Planetary Nebulae, IAU Symp No. 103,
*     >>refer ed by D.R. Flower, (D. Reidel: Holland), 143
      cs = min( 6.0 , 15.836/(te10*te02/te003) )
      call PutCS( 5.5 , t2335 )
      call level2( t2335 )
*
*     Si II 1808, permitted resonance line,
*     osc str from morton et al 88 (apj sup); 
*     all si ii collision data (following 4 lines) are from
*     >>refer Dufton, P.L., & Kingston, A.E. 1991, MNRAS, 248, 827
*     following assumes there is typo in table 1 of dufton and kingston
*     and that they meant 2s 2p^2 ^2D instead of 3d
      call PutCS( 13.01 , t1808 )
      call level2( t1808 )
*
      call PutCS( 3.61 , t1527 )
      call level2( t1527 )
*
      call PutCS( 2.89 , t1305 )
      call level2( t1305 )
*
      call PutCS( 12.25, t1260 )
      call level2( t1260 )
*
*     permitted Si III 1206.5, collision strength from 
*     >>refer Callaway, J. 1994, ADNDT, 57, 9
      cs = min( 7.0 , 1.442 * te10*te03*te03/te01 )
      call PutCS( cs , t1207 )
      call level2( t1207 )
*
*     Si III] 1895, CS=
*     >>refer Dufton, P.L., & Kingston, A.E. 1989, MNRAS, 241, 209
*     >>refer Callaway, J. 1994, ADNDT, 57, 9
*     a=
*     >>refer Nussbaumer, H. 1986, A&A , 155, 205
*     grnd 3s^2 ^1S, upper lev 3p ^3P^o j=0,1,2
      cs = 106. / (te10*te10*te10*te02)
      call PutCS( cs , t1895 )
      call beseq(1.8 , 3.6 , 10.4 , t1895 ,.013)
      em1895 = PopLevels(3) * 0.013 * 1.05e-11
*
*     Si IV 1394, 1403, data from 
*     >>refer Mendoza, C. 1982, in Planetary Nebulae, IAU Symp No. 103,
*     >>refer ed by D.R. Flower, (D. Reidel: Holland), 143
*     cs from 
*     >>refer Dufton, P.L., & Kingston, A.E. 1987, JPhB, 20, 3899
      cs = 6.37 * te10
      call PutCS( cs*0.667, t1394 )
      call PutCS( cs*0.333, t1403 )
      call PutCS(  1.0 , TauDummy )
      call level3( t1403,TauDummy, t1394)
*
*     Si VI 1.96 micron
*     >>refer Saraph, H.E. & Tully, J.A. 1994, A&AS, 107, 29
*     >>chng 96 july 16 had been constant
      cs = max(0.3, min(0.43,0.0448*te20/te003/te003 ))
      call PutCS( cs , Si619 )
      call level2( Si619 )
*
*     Si VII 2148- OIII like, 
*     >>refer Kafatos, M., & Lynch, J.P. 1980, ApJS, 42, 611
      c2148 = popexc(0.4,9.,5.,15.,6.7e4,xIonFracs(14,7))*9.26e-12
      call coladd( 'Si 7' , 2148 , c2148  )
*
*     Si VII ground term, 2.48, 6.51 microns
*     cs 
*     >>refer Butler, K., & Zeippen, C.J. 1994, A&AS, 108, 1
      cs = min( 0.217 , 0.0904*te05*te03/te003/te001 )
      call PutCS( cs , tSi65 )
      cs = min(0.70 , 8.79e-2 *te10*te10/te02 )
      call PutCS( cs , tSi25 )
      cs = min( 0.20 , 9.751e-3 * te20*te03*te03/te003 )
      call PutCS( cs , TauDummy )
      call level3(tSi25,tSi65,TauDummy)
*
*     Si 8 1446, 3727-like, 
*     >>refer Kafatos, M., & Lynch, J.P. 1980, ApJS, 42, 611
      c1446 = popexc(0.4,4.,10.,1.,9.97e4,xIonFracs(14,8))*1.39E-11
      call coladd( 'Si 8' , 1446 , c1446  )
*
*     Si 9 1985, 2150
*     cs, As from
*     >>refer Aggarwal, K.M. 1983, JPhB, 16, L59
*     >>refer Baluja, K.L. 1985, JPhB, 18, L413
      c949 = pop3(9.,5.,1., 0.5913,0.0757,0.225 , 26.3,214.,5.16 ,
     1 7.62e4 , 7.902e4 , p2 , xIonFracs(14,9) , 0. ) * 214. * 2.096E-11
      c1815 = c949 * 1.912 * 0.0516
      c1985 = p2 * 26.3 * 1.0e-11
      call coladd( 'Si 9' , 949 , c949  )
      call coladd( 'Si 9' , 1815 , c1815  )
      call coladd( 'Si 9' , 1985 , c1985  )
*
*     Si 9 3P fine structure lines, A=
*     >>refer Baluja, K.L. 1985, JPhB, 18, L413
*     2.583, 3.9microns
*     CS=
*     >>refer Lennon, D.J. Burke, V.M. 1994, A&AS, 103, 273
      cs01 = min( 0.98 ,
     1 28.51/(te10*te10*te10*te10/te03*te003*te001*te001))
      cs12 = min( 2.7,
     1 81.21/(te10*te10*te10*te10/te01/te01/te001/te001 ) )
      cs02 = min( 0.70, 19.67/ (te10*te10*te10*te10/te03*te001) )
      call PutCS( cs01 , tSi4 )
      call PutCS( cs12 , tSi3 )
      call PutCS( cs02 , TauDummy )
      call level3(tSi4,tSi3,TauDummy)
*
*     5S0 - 3P, cs from, A=guess
*     >>refer Aggarwal, K.M. 1984, ApJS, 54, 1
      c691 = popexc(40.6/sqrte*te10,9.,5.,1e4,2.081e5,xIonFracs(14,9))*
     1 2.88e-11
      call coladd( 'Si 9' , 691 , c691 )
*
*     Si 10 606, actually four lines clumped together.
*     atomic data 
*     >>refer Saha, H.P., & Trefftz, E. 1982, A&A, 116, 224
      c606 = 0.10 * 1.42e-16 * expion( 2.4e5 , xIonFracs(14,10) )
      call coladd( 'Si10' , 606 , c606  )
*
*     Si X 1.43m, A from 
*     >>refer Chandra, S. 1982, SoPh, 75, 133
*     cs from 
*     >>refer Zhang, H.L., Graziani, M., Pradhan, A.K. 1994, A&A, 283, 319
      if( te.le.40500. ) then
        cs = 0.190 * te20/te001
      else
        cs = 24.93 / ( te20*te03*te01*te003*te003 )
      endif
      call PutCS( cs , Si10143 )
      call level2( Si10143 )
*
*     SI 11 582.9, 1909-LIKE, CS=
*     >>refer Berrington, K.A., Burke, P.G., Dufton, P.L., Kingston, A.E.
*     >>refer 1985, ADNDT, 33, 195
*     A=
*     >>refer Muhlethaler, H.P., & Nussbaumer, H. 1976, A&A 48, 109
      c583 = popexc(0.10,1.,9.,1e5,2.47e5,xIonFracs(14,11))*3.4e-11
      call coladd( 'Si11' , 583 , c583  )
*
*     li seq 2s2p and 2s3p, Si XII 499, 521
*     >>refer Cochrane, D.M., & McWhirter, R.W.P. 1983, PhyS, 28, 25
      call ligbar( 14 , tSi499, tSi41, cs2s2p , cs2s3p )
      call PutCS( cs2s2p , tSi499 )
      call PutCS( cs2s2p*0.5 , tSi521 )
      call PutCS(  1.0 , TauDummy )
      call level3( tSi521,TauDummy, tSi499)
*
      call PutCS( cs2s3p , tSi41 )
      call level2( tSi41 )
*
      end
