******************************************************************************
      subroutine strbst( chCard )
      implicit none
*generate abundance set from Fred Hamann's starburst evolution grid
      character chCard*80
      include "ndust.par"
      include "limelm.par"
      include "solar.com"
      include "solars.com"
      include "limext.par"
      include "limpar.par"
      include "varon.com"
      include "varang.com"
      include "nvary.com"
      include "vparm.com"
      include "vformt.com"
      include "nvfpnt.com"
      include "ninput.com"
      include "IOqq.com"
      include "ElmntSym.com"
*
*     local variables
      real zh,zhe,zc,zn,zo,zne,zna,zmg,zal,zsi,zs,zcl,zar,zca,zfe,zco,
     1 zni
      real zLimit , zHigh
      logical lgMatch , lgEOL , lgDebug
      integer i
      real zed , fread , zed2,zed3,zed4,zedlog,sqrzed
*     this is largest stored metallicity
      data zLimit/35.5/
*
      if( lgMatch( 'TRAC',chCard ) ) then
        lgDebug = .true.
      else
        lgDebug = .false.
      endif
*
      i = 5
*     argument is metallicity 
      zed = fread( chCard , i , 76 , lgEOL )
      if( lgDebug ) then
*       trace keyword did appear
*       this will not be used, but must trick the sanity test
        zHigh = zLimit
*       if trace option set, print header now, and init ZED
        write(qq,'('' Abundances relative to H, Z'')')
        write(qq,'(5X,A2,3X,30(3X,A2,1X))') ' Z',chElementSym
        zed = 1e-3
      else if( lgEOL.and. .not.lgDebug ) then
*       no number and trace keyword did not appear
        write(qq,'('' The metallicity must appear on this line.'')')
        stop
      else
        zHigh = zed
      endif
*
*     interpolate on Fred Hamann's set of starburst abundances
*     scan off keys _log or linear
      if( lgMatch( ' LOG',chCard ) ) then
        zed = 10.**zed
        zHigh = zed
      else if( lgMatch('LINE',chCard )  )then
        if( zed.le.0. ) then
          write(qq,'('' Z .le.0 not allowed, Z='',1P,
     1    e10.2)') zed
          stop
        endif
      else
*       log, linear not specified, neg so log
        if( zed.le.0. ) then
          zed = 10.**zed
          zHigh = zed
        endif
      endif
*
*     following if loop only if trace option is set
*     >>chng 97 june 17, get rid of go to
*999  continue
*
      do while (zed.le.zHigh )
        if( zed.lt.1e-3 .or. zed.gt.zLimit ) then
          write(qq,'('' The metallicity must be between 1E-3 and'',1P,
     1    e10.2)')zLimit
          stop
        endif
        zed2 = zed*zed
        zed3 = zed2*zed
        zed4 = zed3*zed
        zedlog = alog(zed)
        sqrzed = sqrt( zed )
*       The value of each element as a function of ZED=[Z]
        zh = 1.081646723 - 0.04600492*zed + 8.6569e-6*zed2
     1     + 1.922e-5*zed3 - 2.0087e-7*zed4
*
*       helium
        zhe = 0.864675891 + 0.044423807*zed + 7.10886e-5*zed2
     1    - 5.3242e-5*zed3 + 5.70194e-7*zed4
        solar(2) = zhe
*
*       li, b, bo unchanged
        solar(3) = 1.
        solar(4) = 1.
        solar(5) = 1.
*
*       carbon
        zc = 0.347489799 + 0.016054107*zed - 0.00185855*zed2
     1    + 5.43015e-5*zed3 - 5.3123e-7*zed4
        solar(6) = zc
*
*       nitrogen
        zn = -0.06549567 + 0.332073984*zed + 0.009146066*zed2
     1    - 0.00054441*zed3 + 6.16363e-6*zed4
        if(zn.lt.0.0) then
          zn = 0.05193*zed
        endif 
        if(zed.lt.0.3) then
          zn = -0.00044731103 + 0.00026453554*zed + 0.52354843*zed2
     1      - 0.41156655*zed3 + 0.1290967*zed4
          if(zn.lt.0.0) then
            zn = 0.000344828 * zed
          endif
        endif 
        solar(7) = zn
*
*       oxygen
        zo = 1.450212747 - 0.05379041*zed + 0.000498919*zed2
     1    + 1.09646e-5*zed3 - 1.8147e-7*zed4
        solar(8) = zo
*
*       neon
        zne = 1.110139023 + 0.002551998*zed - 2.09516e-7*zed3
     1    - 0.00798157*(zedlog)**2
        solar(10) = zne
*
*       fluorine, scale from neon
        solar(9) = solar(10)
*
*       sodium
        zna = 1.072721387 - 0.02391599*(zedlog)**2 
     1    +.068644972*zedlog + 0.017030935 / sqrzed
*       this one is slightly negative at very low Z
        zna = max( 1e-12, zna )
        solar(11) = zna
*
*       magnesium
        zmg = 1.147209646 - 7.9491e-7*zed**3 -.00264458*(zedlog)**2
     1    - 0.00635552*zedlog
        solar(12) = zmg
*
*       aluminium
        zal = 1.068116358 - 0.00520227*sqrzed*zedlog 
     1    -0.01403851*(zedlog)**2 + 0.066186787*zedlog
*       this one is slightly negative at very low Z
        zal = max( 1e-12, zal )
        solar(13) = zal
*
*       silicon
        zsi = 1.067372578 + 0.011818743*zed - 0.00107725*zed2
     1    + 3.66056e-5*zed3 - 3.556e-7*zed4
        solar(14) = zsi
*
*       phosphorus scaled from silicon
        solar(15) = solar(14)
*
*       sulphur
        zs = 1.12000
        solar(16) = zs
*
*       chlorine
        zcl = 1.10000
        solar(17) = zcl
*
*       argon
        zar = 1.091067724 + 2.51124e-6*zed3 
     1    - 0.0039589*sqrzed*zedlog + 0.015686715*zedlog
        solar(18) = zar
*
*       potassium scaled from silicon
        solar(19) = solar(14)
*
*       calcium
        zca = 1.077553875 - 0.00888806*zed + 0.001479866*zed2
     1    - 6.5689e-5*zed3 + 1.16935e-6*zed4
        solar(20) = zca
*
*       iron
        zfe = 0.223713045 + 0.001400746*zed + 0.000624734*zed2
     1    - 3.5629e-5*zed3 + 8.13184e-7*zed4
        solar(26) = zfe
*
*       scandium, scaled from iron
        solar(21) = solar(26)
*
*       titanium, scaled from iron
        solar(22) = solar(26)
*
*       vanadium scaled from iron
        solar(23) = solar(26)
*
*       chromium scaled from iron
        solar(24) = solar(26)
*
*       manganese scaled from iron
        solar(25) = solar(26)
*
*       cobalt
        zco = zfe
        solar(27) = zco
*
*       nickel
        zni = zfe
        solar(28) = zni
*
*       copper scaled from iron
        solar(29) = solar(26)
*
*       zinc  scaled from iron
        solar(30) = solar(26)
*   
*       rescale to true abundances
        solar(1) = 1.
        solar(2) = solar(2) * SolarSave(2)/zh 
        do i=3,limelm
          solar(i) = solar(i) * SolarSave(i)*zed/zh
        end do
*   
        if( lgDebug ) then
          write(qq,'(1P,E10.2,0P,20(F6.2))') zed,(log10(solar(i)),i=1,
     1    limelm)
          if( zed.eq.zLimit ) stop
        endif
*
*       this trick makes sure last one is upper limit
        if( zed.lt.zLimit ) then
          zed = min(zed * 1.5 , zLimit )
        else
          zed = zed * 1.5
        endif
      end do
*
*     vary option
      if( lgVarOn ) then
        nparm = nparm + 1
*       this is number of parameters to feed onto the input line
        nvarxt(nparm) = 1
        chVarFmt(nparm) = '(''ABUNDANCES STARBURST'',F9.5,'' LOG'')'
*       following are upper and lower limits to metallicity range
        varang(1,nparm) = log10( 1e-3 )
        varang(2,nparm) = log10( zLimit )
*       pointer to where to write
        nvfpnt(nparm) = nRead
*       log of metallicity will be argument
        vparm(nparm,1) = log10( zed )
        vincr(nparm) = 0.2
      endif
*
      end
