******************************************************************************
      subroutine strk
      implicit none
*compute stark broadening escape probabilities using Puetter formalism
      include "nhlvl.par"
      include "nhe1lvl.par"
      include "nhe2lvl.par"
      include "nta.par"
      include "TePowers.com"
      include "strkon.com"
      include "he1as.com"
      include "he2as.com"
      include "he1str.com"
      include "he2str.com"
      include "hyas.com"
      include "strkar.com"
      include "htau.com"
      include "htnext.com"
      include "he1tau.com"
      include "he2tau.com"
      include "he1nxt.com"
      include "he2nxt.com"
      include "phycon.com"
      include "touton.com"
*
*     local variables
      integer i , j
      real ah , strkla , stark
*
      if( .not.lgStarkON .or.eden.lt.1e8 ) then
        do j=1,nhlvl
          do i=1,nhlvl
            pestrk(i,j) = 0.
            pestrk(j,i) = 0.
          end do
        end do
        do j=1,nhe1lvl
          do i=1,nhe1lvl
            peshe1(i,j) = 0.
          end do
        end do
        do j=1,nhe2lvl
          do i=1,nhe2lvl
            peshe2(i,j) = 0.
          end do
        end do
        return
      endif
*
*     evaluate Stark escape probability from Puetter Ap.J. 251, 446.
*
*     coefficients for Stark broadening escape probability
*     needs factor of nu/nl ** 3 *xl to be Puetters AH
      ah = 6.9e-6*1000./1e12 / (sqrte*te10*te10*te03*te01*te01) * eden
*     coefficient for all lines except Ly alpha
      stark = 0.264 * ah**0.4
*     coefficient for Ly alpha
      strkla = 0.538*ah*4.*9.875*(sqrte/te10/te03)
*
*     Lyman lines always have outer optical depths
      pestrk(2,1) = strkla /2. * ( max(1.,htnext(2,1))**(-0.75)+
     1max( 1., htlim(2,1)/10. , (htlim(2,1)-htnext(2,1)) ) **(-0.75))
      pestrk(2,1) = min(.01, pestrk(2,1) )
      pestrk(1,2) = pestrk(2,1) * hyas(2,1)
*
      peshe1(2,1) = strkla /2. * ( max(1.,he1nxt(2,1))**(-0.75)+
     1max(1.,he1lim(2,1)/10.,(he1lim(2,1)-he1nxt(2,1)) ) **(-0.75))
      peshe1(2,1) = min(.01, peshe1(2,1) )
      peshe1(1,2) = peshe1(2,1) * He1EinA(2,1)
*
      peshe2(2,1) = strkla /2. * ( max(1.,he2nxt(2,1))**(-0.75)+
     1max(1.,he2lim(2,1)/10.,(he2lim(2,1)-he2nxt(2,1)) ) **(-0.75))
      peshe2(2,1) = min(.01, peshe2(2,1) )
      peshe2(1,2) = peshe2(2,1) * he2as(2,1)
*
      do j=3,nhlvl
        pestrk(j,1) = stark*strkar(j,1)/2.*(max(1.,htnext(j,1))**(-0.6)
     1  +max( htlim(j,1)/10. , (htlim(j,1)-htnext(j,1)) ,1.)**(-0.6))
        pestrk(j,1) = min( .01 , pestrk(j,1) )
        pestrk(1,j) = hyas(j,1) * pestrk(j,1)
      end do
      do j=3,nhe1lvl
        peshe1(j,1) = strkla /2. * ( max(1.,he1nxt(j,1))**(-0.75)+
     1  max(1.,he1lim(j,1)/10.,(he1lim(j,1)-he1nxt(j,1)) ) **(-0.75))
        peshe1(j,1) = min(.01, peshe1(j,1) )
        peshe1(1,j) = peshe1(j,1) * He1EinA(j,1)
      end do
*
      do j=3,nhe2lvl
        peshe2(j,1) = strkla /2. * ( max(1.,he2nxt(j,1))**(-0.75)+
     1  max(1.,he2lim(j,1)/10.,(he2lim(j,1)-he2nxt(j,1)) ) **(-0.75))
        peshe2(j,1) = min(.01, peshe2(j,1) )
        peshe2(1,j) = peshe2(j,1) * he2as(j,1)
      end do
*
*     all other lines
      if( lgTauOutOn ) then
*       outer optical depths defined, Ly alpha first
*       don't add Stark if tau less than 100
*       all other lines
        do i=2,nhlvl-1
           do j=i+1,nhlvl
             pestrk(j,i) = stark*strkar(j,i)/2.*(max(1.,
     1       htnext(j,i))**(-0.6) +max( htlim(j,i)/10. ,
     2       (htlim(j,i)-htnext(j,i)) ,1.)**(-0.6))
             pestrk(j,i) = min( .01 , pestrk(j,i) )
             pestrk(i,j) = hyas(j,i) * pestrk(j,i)
          end do
        end do
        do i=2,nhe1lvl-1
          do j=i+1,nhe1lvl
            peshe1(j,i) = stark*strkar(j,i)/2.*(max(1.,
     1       he1nxt(j,i))**(-0.6) +max( he1lim(j,i)/10. ,
     2       (he1lim(j,i)-he1nxt(j,i)) ,1.)**(-0.6))
             peshe1(j,i) = min( .01 , peshe1(j,i) )
             peshe1(i,j) = He1EinA(j,i) * peshe1(j,i)
          end do
        end do
*
         do i=2,nhe2lvl-1
            do j=i+1,nhe2lvl
               peshe2(j,i) = stark*strkar(j,i)/2.*(max(1.,
     1         he2nxt(j,i))**(-0.6) +max( he2lim(j,i)/10. ,
     2         (he2lim(j,i)-he2nxt(j,i)) ,1.)**(-0.6))
               peshe2(j,i) = min( .01 , peshe2(j,i) )
               peshe2(i,j) = he2as(j,i) * peshe2(j,i)
            end do
         end do
      else
*       outer optical depths not defined
        do i=2,nhlvl-1
          do j=i+1,nhlvl
            pestrk(j,i) = min(.01,stark*strkar(j,i)*
     1      max(1.,htnext(j,i))** (-0.6))
            pestrk(i,j) = hyas(j,i) * pestrk(j,i)
          end do
        end do
        do i=2,nhe1lvl-1
          do j=i+1,nhe1lvl
            peshe1(j,i) = min(.01,stark*strkar(j,i)*
     1      max(1.,he1nxt(j,i))** (-0.6))
            peshe1(i,j) = He1EinA(j,i) * peshe1(j,i)
            peshe2(i,j) = he2as(j,i) * peshe2(j,i)
          end do
        end do
*
       do i=2,nhe2lvl-1
         do j=i+1,nhe2lvl
           peshe2(j,i) = min(.01,stark*strkar(j,i)*
     1     max(1.,he2nxt(j,i))** (-0.6))
           peshe2(i,j) = he2as(j,i) * peshe2(j,i)
         end do
        end do
      endif
*
      end
